/********************************************************************************
** Form generated from reading UI file 'preferences_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef PREFERENCES_DIALOG_H
#define PREFERENCES_DIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFontComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/info/job_settings_widget.h"
#include "mkvtoolnix-gui/util/basic_spin_box.h"
#include "mkvtoolnix-gui/util/basic_tab_widget.h"
#include "mkvtoolnix-gui/util/character_set_combo_box.h"
#include "mkvtoolnix-gui/util/language_display_widget.h"
#include "mkvtoolnix-gui/util/side_by_side_multi_select.h"
#include "mkvtoolnix-gui/util/string_list_configuration_widget.h"

namespace mtx {
namespace gui {

class Ui_PreferencesDialog
{
public:
    QVBoxLayout *verticalLayout_24;
    QSplitter *pagesSplitter;
    QTreeView *pageSelector;
    QStackedWidget *pages;
    QWidget *pGuiGeneral;
    QVBoxLayout *verticalLayout_10;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout_4;
    QLabel *label_24;
    QComboBox *cbGuiInterfaceLanguage;
    QLabel *label_3;
    mtx::gui::Util::BasicSpinBox *sbGuiNumRecentlyUsedStrings;
    QHBoxLayout *horizontalLayout_10;
    QFontComboBox *fcbGuiFontFamily;
    mtx::gui::Util::BasicSpinBox *sbGuiFontPointSize;
    QLabel *label_12;
    QComboBox *cbGuiPalette;
    QLabel *cbGuiPaletteLabel;
    QCheckBox *cbGuiStayOnTop;
    QCheckBox *cbGuiDisableHighDPIScaling;
    QCheckBox *cbGuiDisableToolTips;
    QCheckBox *cbGuiCheckForUpdates;
    QCheckBox *cbGuiUseLegacyFontMIMETypes;
    QCheckBox *cbGuiShowDebuggingMenu;
    QGroupBox *groupBox_16;
    QVBoxLayout *verticalLayout_30;
    QGridLayout *gridLayout_9;
    QLabel *label_9;
    QComboBox *cbGuiTabPositions;
    QCheckBox *cbGuiElideTabHeaderLabels;
    QCheckBox *cbGuiShowToolSelector;
    QCheckBox *cbGuiShowMoveUpDownButtons;
    QGroupBox *groupBox_6;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *cbGuiWarnBeforeClosingModifiedTabs;
    QCheckBox *cbGuiWarnBeforeAbortingJobs;
    QCheckBox *cbGuiWarnBeforeOverwriting;
    QSpacerItem *verticalSpacer_2;
    QWidget *pGuiOftenUsedSelections;
    QVBoxLayout *verticalLayout_8;
    QTabWidget *tbOftenUsedXYZ;
    QWidget *oftenUsedLanguagesTab;
    QVBoxLayout *verticalLayout_17;
    mtx::gui::Util::SideBySideMultiSelect *tbOftenUsedLanguages;
    QCheckBox *cbOftenUsedLanguagesOnly;
    QWidget *oftenUsedRegionsTab;
    QVBoxLayout *verticalLayout_18;
    mtx::gui::Util::SideBySideMultiSelect *tbOftenUsedRegions;
    QCheckBox *cbOftenUsedRegionsOnly;
    QWidget *oftenUsedCharacterSetsTab;
    QVBoxLayout *verticalLayout_19;
    mtx::gui::Util::SideBySideMultiSelect *tbOftenUsedCharacterSets;
    QCheckBox *cbOftenUsedCharacterSetsOnly;
    QWidget *pGuiLanguages;
    QVBoxLayout *verticalLayout_52;
    QGroupBox *groupBox_27;
    QVBoxLayout *verticalLayout_49;
    QGridLayout *gridLayout_11;
    QLabel *label_26;
    QComboBox *cbGuiBCP47LanguageEditingMode;
    QLabel *label_11;
    QComboBox *cbGuiBCP47NormalizationMode;
    QCheckBox *cbUseISO639_3Languages;
    QGroupBox *groupBox_26;
    QHBoxLayout *horizontalLayout_18;
    QTreeWidget *twGuiLanguageShortcuts;
    QVBoxLayout *verticalLayout_48;
    QPushButton *pbGuiAddLanguageShortcut;
    QPushButton *pbGuiEditLanguageShortcut;
    QPushButton *pbGuiRemoveLanguageShortcuts;
    QSpacerItem *verticalSpacer_3;
    QWidget *pMergeGeneral;
    QVBoxLayout *verticalLayout_45;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_4;
    QGridLayout *gridLayout_2;
    QHBoxLayout *horizontalLayout_16;
    QLineEdit *leMMediaInfoExe;
    QPushButton *pbMBrowseMediaInfoExe;
    QComboBox *cbMProcessPriority;
    QLabel *label_19;
    QLabel *label_16;
    QComboBox *cbMWarnMissingAudioTrack;
    QLabel *label_6;
    QComboBox *cbMClearMergeSettings;
    QDoubleSpinBox *cbMProbeRangePercentage;
    QLabel *label_20;
    QLabel *label_5;
    QComboBox *cbMDefaultCommandLineEscapeMode;
    QLabel *label_21;
    QCheckBox *cbMEnsureAtLeastOneTrackEnabled;
    QGroupBox *groupBox_23;
    QVBoxLayout *verticalLayout_43;
    QGridLayout *gridLayout_10;
    QLabel *label_23;
    QComboBox *cbMDragAndDropFilesPolicy;
    QLabel *label_13;
    QComboBox *cbMAddingAppendingFilesPolicy;
    QLabel *label_25;
    QComboBox *cbMDragAndDropDirectoriesPolicy;
    QCheckBox *cbMAlwaysCreateSettingsForVideoFiles;
    QCheckBox *cbMShowDNDZones;
    QCheckBox *cbMSortFilesTracksByTypeWhenAdding;
    QCheckBox *cbMReconstructSequencesWhenAdding;
    QGroupBox *groupBox_25;
    QVBoxLayout *verticalLayout_47;
    QCheckBox *cbMAttachmentAlwaysSkipForExistingName;
    QSpacerItem *verticalSpacer_12;
    QWidget *pMergeLayout;
    QVBoxLayout *verticalLayout_53;
    QGroupBox *groupBox_12;
    QVBoxLayout *verticalLayout_20;
    QCheckBox *cbMAlwaysShowOutputFileControls;
    QLabel *cbMTrackPropertiesLayoutLabel;
    QHBoxLayout *horizontalLayout_8;
    QSpacerItem *horizontalSpacer_8;
    QVBoxLayout *verticalLayout_12;
    QRadioButton *rbMTrackPropertiesLayoutHorizontalScrollArea;
    QRadioButton *rbMTrackPropertiesLayoutHorizontalTwoColumns;
    QRadioButton *rbMTrackPropertiesLayoutVerticalTabWidget;
    QGroupBox *groupBox_24;
    QVBoxLayout *verticalLayout_46;
    QCheckBox *cbMUseFileAndTrackColors;
    QHBoxLayout *horizontalLayout_3;
    QListWidget *lwMFileColors;
    QVBoxLayout *verticalLayout_37;
    QPushButton *pbMAddFileColor;
    QPushButton *pbMRemoveFileColors;
    QPushButton *pbMEditFileColor;
    QSpacerItem *verticalSpacer;
    QPushButton *pbMRevertFileColorsToDefault;
    QSpacerItem *verticalSpacer_7;
    QSpacerItem *horizontalSpacer_11;
    QSpacerItem *verticalSpacer_13;
    QWidget *pMergePredefinedValues;
    QVBoxLayout *verticalLayout_39;
    QHBoxLayout *horizontalLayout_15;
    QGroupBox *gpMPredefinedVideoTrackNames;
    QVBoxLayout *verticalLayout_50;
    mtx::gui::Util::StringListConfigurationWidget *lwMPredefinedVideoTrackNames;
    QGroupBox *gpMPredefinedAudioTrackNames;
    QVBoxLayout *verticalLayout_51;
    mtx::gui::Util::StringListConfigurationWidget *lwMPredefinedAudioTrackNames;
    QGroupBox *gpMPredefinedSubtitleTrackNames;
    QVBoxLayout *verticalLayout_21;
    mtx::gui::Util::StringListConfigurationWidget *lwMPredefinedSubtitleTrackNames;
    QHBoxLayout *horizontalLayout_14;
    QGroupBox *gbMPredefinedSplitSizes;
    QVBoxLayout *verticalLayout_22;
    mtx::gui::Util::StringListConfigurationWidget *lwMPredefinedSplitSizes;
    QGroupBox *gbMPredefinedSplitDurations;
    QVBoxLayout *verticalLayout_38;
    mtx::gui::Util::StringListConfigurationWidget *lwMPredefinedSplitDurations;
    QWidget *pMergeDefaultsForTracks;
    QVBoxLayout *verticalLayout_23;
    QGroupBox *groupBox_11;
    QGridLayout *gridLayout_6;
    QLabel *label_15;
    QHBoxLayout *horizontalLayout_9;
    QLineEdit *leMDefaultAdditionalCommandLineOptions;
    QPushButton *pbMEditDefaultAdditionalCommandLineOptions;
    QGroupBox *groupBox_10;
    QVBoxLayout *verticalLayout_6;
    QCheckBox *cbMAutoSetFileTitle;
    QCheckBox *cbMAutoClearFileTitle;
    QCheckBox *cbMSetAudioDelayFromFileName;
    QCheckBox *cbMDisableDefaultTrackForSubtitles;
    QCheckBox *cbMDisableCompressionForAllTrackTypes;
    QCheckBox *cbMEnableDialogNormGainRemoval;
    QGridLayout *gridLayout_12;
    QCheckBox *cbMDeriveForcedDisplayFlagSubtitles;
    mtx::gui::Util::CharacterSetComboBox *cbMDefaultSubtitleCharset;
    QCheckBox *cbMDeriveCommentaryFlag;
    mtx::gui::Util::LanguageDisplayWidget *ldwMSetOriginalLanguageFlagLanguage;
    QCheckBox *cbMSetOriginalLanguageFlagLanguage;
    QHBoxLayout *horizontalLayout_19;
    QLineEdit *leMDeriveCommentaryFlagRE;
    QPushButton *pbMDeriveCommentaryFlagRERevert;
    QCheckBox *cbMDeriveHearingImpairedFlag;
    QHBoxLayout *horizontalLayout_17;
    QLineEdit *leMDeriveHearingImpairedFlagRE;
    QPushButton *pbMDeriveHearingImpairedFlagRERevert;
    QHBoxLayout *horizontalLayout;
    QLineEdit *leMDeriveForcedDisplayFlagSubtitlesRE;
    QPushButton *pbMDeriveForcedDisplayFlagSubtitlesRERevert;
    QLabel *label_4;
    QCheckBox *cbMDeriveFlagsFromTrackNames;
    QGroupBox *groupBox_9;
    QGridLayout *gridLayout_5;
    QLabel *lDefaultAudioTrackLanguage;
    mtx::gui::Util::LanguageDisplayWidget *ldwMDefaultAudioTrackLanguage;
    mtx::gui::Util::LanguageDisplayWidget *ldwMDefaultSubtitleTrackLanguage;
    mtx::gui::Util::LanguageDisplayWidget *ldwMDefaultVideoTrackLanguage;
    QLabel *lDefaultVideoTrackLanguage;
    QLabel *lDefaultSubtitleTrackLanguage;
    QLabel *lWhenToSetDefaultLanguage;
    QComboBox *cbMWhenToSetDefaultLanguage;
    QSpacerItem *verticalSpacer_8;
    QWidget *pMergeDerivingTrackLanguageFromFileName;
    QVBoxLayout *verticalLayout_35;
    QGroupBox *groupBox_18;
    QGridLayout *gridLayout_8;
    QLabel *lDeriveAudioTrackLanguageFromFileName;
    QComboBox *cbMDeriveAudioTrackLanguageFromFileName;
    QLabel *lDeriveVideoTrackLanguageFromFileName;
    QComboBox *cbMDeriveVideoTrackLanguageFromFileName;
    QLabel *lDeriveSubtitleTrackLanguageFromFileName;
    QComboBox *cbMDeriveSubtitleTrackLanguageFromFileName;
    QLabel *label_18;
    QHBoxLayout *horizontalLayout_13;
    QLineEdit *leMDeriveTrackLanguageBoundaryChars;
    QPushButton *pbMDeriveTrackLanguageRevertBoundaryChars;
    QGroupBox *groupBox_19;
    QVBoxLayout *verticalLayout_36;
    mtx::gui::Util::SideBySideMultiSelect *tbMDeriveTrackLanguageRecognizedLanguages;
    QWidget *pMergeOutput;
    QVBoxLayout *verticalLayout_7;
    QGroupBox *groupBox_5;
    QVBoxLayout *verticalLayout_5;
    QCheckBox *cbMAutoSetDestinationFileName;
    QCheckBox *cbMAutoSetDestinationOnlyForVideoFiles;
    QCheckBox *cbMAutoSetDestinationFromTitle;
    QCheckBox *cbMAutoSetDestinationFromDirectory;
    QGroupBox *gbMAutoSetDestinationDirectory;
    QVBoxLayout *verticalLayout_31;
    QRadioButton *rbMAutoSetDestinationSameDirectory;
    QRadioButton *rbMAutoSetDestinationPreviousDirectory;
    QRadioButton *rbMAutoSetDestinationRelativeDirectory;
    QHBoxLayout *horizontalLayout_7;
    QSpacerItem *horizontalSpacer_4;
    QComboBox *cbMAutoSetDestinationRelativeDirectory;
    QRadioButton *rbMAutoSetDestinationFixedDirectory;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_3;
    QComboBox *cbMAutoSetDestinationFixedDirectory;
    QPushButton *pbMAutoSetDestinationBrowseFixedDirectory;
    QCheckBox *cbMUniqueOutputFileNames;
    QCheckBox *cbMAutoClearOutputFileName;
    QGroupBox *groupBox_22;
    QVBoxLayout *verticalLayout_42;
    mtx::gui::Util::StringListConfigurationWidget *lwMRecentDestinationDirectories;
    QWidget *pMergeEnableTracks;
    QVBoxLayout *verticalLayout_13;
    QGroupBox *groupBox_20;
    QVBoxLayout *verticalLayout_34;
    mtx::gui::Util::SideBySideMultiSelect *tbMEnableMuxingTracksByType;
    QGroupBox *groupBox_7;
    QVBoxLayout *verticalLayout_44;
    QCheckBox *cbMEnableMuxingTracksByLanguage;
    mtx::gui::Util::SideBySideMultiSelect *tbMEnableMuxingTracksByLanguage;
    QGroupBox *gbMEnableMuxingGeneral;
    QVBoxLayout *verticalLayout_9;
    QLabel *lMEnableMuxingAllTracksOfType;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QCheckBox *cbMEnableMuxingAllVideoTracks;
    QSpacerItem *horizontalSpacer_9;
    QCheckBox *cbMEnableMuxingAllAudioTracks;
    QSpacerItem *horizontalSpacer_10;
    QCheckBox *cbMEnableMuxingAllSubtitleTracks;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *cbMEnableMuxingForcedSubtitleTracks;
    QWidget *pMergePlaylists;
    QVBoxLayout *verticalLayout_40;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_54;
    QGridLayout *gridLayout;
    QLabel *label;
    QComboBox *cbMScanPlaylistsPolicy;
    QLabel *label_2;
    mtx::gui::Util::BasicSpinBox *sbMMinPlaylistDuration;
    QCheckBox *cbMIgnorePlaylistsForMenus;
    QGroupBox *groupBox_21;
    QVBoxLayout *verticalLayout_16;
    QCheckBox *cbMAddBlurayCovers;
    QSpacerItem *verticalSpacer_6;
    QWidget *pInfoGeneral;
    QVBoxLayout *verticalLayout_33;
    QGroupBox *groupBox_17;
    QVBoxLayout *verticalLayout_32;
    mtx::gui::Info::JobSettingsWidget *wIDefaultJobSettings;
    QSpacerItem *verticalSpacer_11;
    QWidget *pHeaderEditorGeneral;
    QVBoxLayout *verticalLayout_29;
    QGroupBox *groupBox_15;
    QVBoxLayout *verticalLayout_41;
    QHBoxLayout *horizontalLayout_11;
    QLabel *label_14;
    QComboBox *cbHEDroppedFilesPolicy;
    QCheckBox *cbHEDateTimeInUTC;
    QSpacerItem *verticalSpacer_10;
    QWidget *pChapterEditorGeneral;
    QVBoxLayout *verticalLayout_15;
    QGroupBox *groupBox_8;
    QVBoxLayout *verticalLayout_11;
    QCheckBox *cbCEDropLastFromBlurayPlaylist;
    QHBoxLayout *horizontalLayout_12;
    QLabel *label_17;
    mtx::gui::Util::CharacterSetComboBox *cbCETextFileCharacterSet;
    QGroupBox *groupBox_13;
    QGridLayout *gridLayout_3;
    QLineEdit *leCENameTemplate;
    QLabel *label_7;
    mtx::gui::Util::LanguageDisplayWidget *ldwCEDefaultLanguage;
    QLabel *label_10;
    QSpacerItem *verticalSpacer_4;
    QWidget *pJobsGeneral;
    QVBoxLayout *verticalLayout_14;
    QGroupBox *groupBox_4;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *cbGuiSwitchToJobOutputAfterStarting;
    QCheckBox *cbGuiUseDefaultJobDescription;
    QCheckBox *cbGuiShowOutputOfAllJobs;
    QCheckBox *cbGuiResetJobWarningErrorCountersOnExit;
    QCheckBox *cbGuiRemoveOutputFileOnJobFailure;
    QGridLayout *gridLayout_7;
    QCheckBox *cbGuiRemoveOldJobs;
    QCheckBox *cbGuiRemoveJobsOnExit;
    QCheckBox *cbGuiRemoveJobs;
    QComboBox *cbGuiJobRemovalPolicy;
    mtx::gui::Util::BasicSpinBox *sbGuiRemoveOldJobsDays;
    QComboBox *cbGuiJobRemovalOnExitPolicy;
    QLabel *label_22;
    mtx::gui::Util::BasicSpinBox *sbGuiMaximumConcurrentJobs;
    QSpacerItem *verticalSpacer_5;
    QWidget *pJobsExecutePrograms;
    QVBoxLayout *verticalLayout_28;
    QGroupBox *groupBox_14;
    QVBoxLayout *verticalLayout_27;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_6;
    QPushButton *pbJobsAddProgram;
    QSpacerItem *horizontalSpacer_5;
    QStackedWidget *swJobsPrograms;
    QWidget *pJobsNoPrograms;
    QVBoxLayout *verticalLayout_25;
    QHBoxLayout *horizontalLayout_6;
    QLabel *label_8;
    QSpacerItem *horizontalSpacer_7;
    QSpacerItem *verticalSpacer_9;
    QWidget *pJobsExistingPrograms;
    QVBoxLayout *verticalLayout_26;
    mtx::gui::Util::BasicTabWidget *twJobsPrograms;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *mtx__gui__PreferencesDialog)
    {
        if (mtx__gui__PreferencesDialog->objectName().isEmpty())
            mtx__gui__PreferencesDialog->setObjectName("mtx__gui__PreferencesDialog");
        mtx__gui__PreferencesDialog->resize(850, 745);
        verticalLayout_24 = new QVBoxLayout(mtx__gui__PreferencesDialog);
        verticalLayout_24->setObjectName("verticalLayout_24");
        pagesSplitter = new QSplitter(mtx__gui__PreferencesDialog);
        pagesSplitter->setObjectName("pagesSplitter");
        pagesSplitter->setOrientation(Qt::Horizontal);
        pagesSplitter->setChildrenCollapsible(false);
        pageSelector = new QTreeView(pagesSplitter);
        pageSelector->setObjectName("pageSelector");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(pageSelector->sizePolicy().hasHeightForWidth());
        pageSelector->setSizePolicy(sizePolicy);
        pageSelector->setMinimumSize(QSize(100, 0));
        pageSelector->setEditTriggers(QAbstractItemView::NoEditTriggers);
        pageSelector->setIconSize(QSize(48, 48));
        pageSelector->setTextElideMode(Qt::ElideNone);
        pageSelector->setHeaderHidden(true);
        pageSelector->setExpandsOnDoubleClick(true);
        pagesSplitter->addWidget(pageSelector);
        pages = new QStackedWidget(pagesSplitter);
        pages->setObjectName("pages");
        pGuiGeneral = new QWidget();
        pGuiGeneral->setObjectName("pGuiGeneral");
        verticalLayout_10 = new QVBoxLayout(pGuiGeneral);
        verticalLayout_10->setObjectName("verticalLayout_10");
        verticalLayout_10->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(pGuiGeneral);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName("gridLayout_4");
        label_24 = new QLabel(groupBox);
        label_24->setObjectName("label_24");

        gridLayout_4->addWidget(label_24, 3, 0, 1, 1);

        cbGuiInterfaceLanguage = new QComboBox(groupBox);
        cbGuiInterfaceLanguage->setObjectName("cbGuiInterfaceLanguage");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbGuiInterfaceLanguage->sizePolicy().hasHeightForWidth());
        cbGuiInterfaceLanguage->setSizePolicy(sizePolicy1);

        gridLayout_4->addWidget(cbGuiInterfaceLanguage, 0, 1, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout_4->addWidget(label_3, 0, 0, 1, 1);

        sbGuiNumRecentlyUsedStrings = new mtx::gui::Util::BasicSpinBox(groupBox);
        sbGuiNumRecentlyUsedStrings->setObjectName("sbGuiNumRecentlyUsedStrings");
        sbGuiNumRecentlyUsedStrings->setMinimum(1);
        sbGuiNumRecentlyUsedStrings->setMaximum(9999);

        gridLayout_4->addWidget(sbGuiNumRecentlyUsedStrings, 3, 1, 1, 1);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        fcbGuiFontFamily = new QFontComboBox(groupBox);
        fcbGuiFontFamily->setObjectName("fcbGuiFontFamily");
        sizePolicy1.setHeightForWidth(fcbGuiFontFamily->sizePolicy().hasHeightForWidth());
        fcbGuiFontFamily->setSizePolicy(sizePolicy1);

        horizontalLayout_10->addWidget(fcbGuiFontFamily);

        sbGuiFontPointSize = new mtx::gui::Util::BasicSpinBox(groupBox);
        sbGuiFontPointSize->setObjectName("sbGuiFontPointSize");
        sbGuiFontPointSize->setMinimum(5);

        horizontalLayout_10->addWidget(sbGuiFontPointSize);


        gridLayout_4->addLayout(horizontalLayout_10, 1, 1, 1, 1);

        label_12 = new QLabel(groupBox);
        label_12->setObjectName("label_12");

        gridLayout_4->addWidget(label_12, 1, 0, 1, 1);

        cbGuiPalette = new QComboBox(groupBox);
        cbGuiPalette->addItem(QString());
        cbGuiPalette->addItem(QString());
        cbGuiPalette->addItem(QString());
        cbGuiPalette->setObjectName("cbGuiPalette");

        gridLayout_4->addWidget(cbGuiPalette, 2, 1, 1, 1);

        cbGuiPaletteLabel = new QLabel(groupBox);
        cbGuiPaletteLabel->setObjectName("cbGuiPaletteLabel");

        gridLayout_4->addWidget(cbGuiPaletteLabel, 2, 0, 1, 1);


        verticalLayout->addLayout(gridLayout_4);

        cbGuiStayOnTop = new QCheckBox(groupBox);
        cbGuiStayOnTop->setObjectName("cbGuiStayOnTop");

        verticalLayout->addWidget(cbGuiStayOnTop);

        cbGuiDisableHighDPIScaling = new QCheckBox(groupBox);
        cbGuiDisableHighDPIScaling->setObjectName("cbGuiDisableHighDPIScaling");

        verticalLayout->addWidget(cbGuiDisableHighDPIScaling);

        cbGuiDisableToolTips = new QCheckBox(groupBox);
        cbGuiDisableToolTips->setObjectName("cbGuiDisableToolTips");

        verticalLayout->addWidget(cbGuiDisableToolTips);

        cbGuiCheckForUpdates = new QCheckBox(groupBox);
        cbGuiCheckForUpdates->setObjectName("cbGuiCheckForUpdates");

        verticalLayout->addWidget(cbGuiCheckForUpdates);

        cbGuiUseLegacyFontMIMETypes = new QCheckBox(groupBox);
        cbGuiUseLegacyFontMIMETypes->setObjectName("cbGuiUseLegacyFontMIMETypes");

        verticalLayout->addWidget(cbGuiUseLegacyFontMIMETypes);

        cbGuiShowDebuggingMenu = new QCheckBox(groupBox);
        cbGuiShowDebuggingMenu->setObjectName("cbGuiShowDebuggingMenu");

        verticalLayout->addWidget(cbGuiShowDebuggingMenu);


        verticalLayout_10->addWidget(groupBox);

        groupBox_16 = new QGroupBox(pGuiGeneral);
        groupBox_16->setObjectName("groupBox_16");
        verticalLayout_30 = new QVBoxLayout(groupBox_16);
        verticalLayout_30->setObjectName("verticalLayout_30");
        gridLayout_9 = new QGridLayout();
        gridLayout_9->setObjectName("gridLayout_9");
        label_9 = new QLabel(groupBox_16);
        label_9->setObjectName("label_9");

        gridLayout_9->addWidget(label_9, 0, 0, 1, 1);

        cbGuiTabPositions = new QComboBox(groupBox_16);
        cbGuiTabPositions->setObjectName("cbGuiTabPositions");
        sizePolicy1.setHeightForWidth(cbGuiTabPositions->sizePolicy().hasHeightForWidth());
        cbGuiTabPositions->setSizePolicy(sizePolicy1);

        gridLayout_9->addWidget(cbGuiTabPositions, 0, 1, 1, 1);


        verticalLayout_30->addLayout(gridLayout_9);

        cbGuiElideTabHeaderLabels = new QCheckBox(groupBox_16);
        cbGuiElideTabHeaderLabels->setObjectName("cbGuiElideTabHeaderLabels");

        verticalLayout_30->addWidget(cbGuiElideTabHeaderLabels);

        cbGuiShowToolSelector = new QCheckBox(groupBox_16);
        cbGuiShowToolSelector->setObjectName("cbGuiShowToolSelector");

        verticalLayout_30->addWidget(cbGuiShowToolSelector);

        cbGuiShowMoveUpDownButtons = new QCheckBox(groupBox_16);
        cbGuiShowMoveUpDownButtons->setObjectName("cbGuiShowMoveUpDownButtons");

        verticalLayout_30->addWidget(cbGuiShowMoveUpDownButtons);


        verticalLayout_10->addWidget(groupBox_16);

        groupBox_6 = new QGroupBox(pGuiGeneral);
        groupBox_6->setObjectName("groupBox_6");
        verticalLayout_3 = new QVBoxLayout(groupBox_6);
        verticalLayout_3->setObjectName("verticalLayout_3");
        cbGuiWarnBeforeClosingModifiedTabs = new QCheckBox(groupBox_6);
        cbGuiWarnBeforeClosingModifiedTabs->setObjectName("cbGuiWarnBeforeClosingModifiedTabs");

        verticalLayout_3->addWidget(cbGuiWarnBeforeClosingModifiedTabs);

        cbGuiWarnBeforeAbortingJobs = new QCheckBox(groupBox_6);
        cbGuiWarnBeforeAbortingJobs->setObjectName("cbGuiWarnBeforeAbortingJobs");

        verticalLayout_3->addWidget(cbGuiWarnBeforeAbortingJobs);

        cbGuiWarnBeforeOverwriting = new QCheckBox(groupBox_6);
        cbGuiWarnBeforeOverwriting->setObjectName("cbGuiWarnBeforeOverwriting");

        verticalLayout_3->addWidget(cbGuiWarnBeforeOverwriting);


        verticalLayout_10->addWidget(groupBox_6);

        verticalSpacer_2 = new QSpacerItem(20, 68, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_10->addItem(verticalSpacer_2);

        pages->addWidget(pGuiGeneral);
        pGuiOftenUsedSelections = new QWidget();
        pGuiOftenUsedSelections->setObjectName("pGuiOftenUsedSelections");
        verticalLayout_8 = new QVBoxLayout(pGuiOftenUsedSelections);
        verticalLayout_8->setObjectName("verticalLayout_8");
        verticalLayout_8->setContentsMargins(0, 0, 0, 0);
        tbOftenUsedXYZ = new QTabWidget(pGuiOftenUsedSelections);
        tbOftenUsedXYZ->setObjectName("tbOftenUsedXYZ");
        oftenUsedLanguagesTab = new QWidget();
        oftenUsedLanguagesTab->setObjectName("oftenUsedLanguagesTab");
        verticalLayout_17 = new QVBoxLayout(oftenUsedLanguagesTab);
        verticalLayout_17->setObjectName("verticalLayout_17");
        tbOftenUsedLanguages = new mtx::gui::Util::SideBySideMultiSelect(oftenUsedLanguagesTab);
        tbOftenUsedLanguages->setObjectName("tbOftenUsedLanguages");
        tbOftenUsedLanguages->setFocusPolicy(Qt::StrongFocus);

        verticalLayout_17->addWidget(tbOftenUsedLanguages);

        cbOftenUsedLanguagesOnly = new QCheckBox(oftenUsedLanguagesTab);
        cbOftenUsedLanguagesOnly->setObjectName("cbOftenUsedLanguagesOnly");

        verticalLayout_17->addWidget(cbOftenUsedLanguagesOnly);

        tbOftenUsedXYZ->addTab(oftenUsedLanguagesTab, QString());
        oftenUsedRegionsTab = new QWidget();
        oftenUsedRegionsTab->setObjectName("oftenUsedRegionsTab");
        verticalLayout_18 = new QVBoxLayout(oftenUsedRegionsTab);
        verticalLayout_18->setObjectName("verticalLayout_18");
        tbOftenUsedRegions = new mtx::gui::Util::SideBySideMultiSelect(oftenUsedRegionsTab);
        tbOftenUsedRegions->setObjectName("tbOftenUsedRegions");
        tbOftenUsedRegions->setFocusPolicy(Qt::StrongFocus);

        verticalLayout_18->addWidget(tbOftenUsedRegions);

        cbOftenUsedRegionsOnly = new QCheckBox(oftenUsedRegionsTab);
        cbOftenUsedRegionsOnly->setObjectName("cbOftenUsedRegionsOnly");

        verticalLayout_18->addWidget(cbOftenUsedRegionsOnly);

        tbOftenUsedXYZ->addTab(oftenUsedRegionsTab, QString());
        oftenUsedCharacterSetsTab = new QWidget();
        oftenUsedCharacterSetsTab->setObjectName("oftenUsedCharacterSetsTab");
        verticalLayout_19 = new QVBoxLayout(oftenUsedCharacterSetsTab);
        verticalLayout_19->setObjectName("verticalLayout_19");
        tbOftenUsedCharacterSets = new mtx::gui::Util::SideBySideMultiSelect(oftenUsedCharacterSetsTab);
        tbOftenUsedCharacterSets->setObjectName("tbOftenUsedCharacterSets");
        tbOftenUsedCharacterSets->setFocusPolicy(Qt::StrongFocus);

        verticalLayout_19->addWidget(tbOftenUsedCharacterSets);

        cbOftenUsedCharacterSetsOnly = new QCheckBox(oftenUsedCharacterSetsTab);
        cbOftenUsedCharacterSetsOnly->setObjectName("cbOftenUsedCharacterSetsOnly");

        verticalLayout_19->addWidget(cbOftenUsedCharacterSetsOnly);

        tbOftenUsedXYZ->addTab(oftenUsedCharacterSetsTab, QString());

        verticalLayout_8->addWidget(tbOftenUsedXYZ);

        pages->addWidget(pGuiOftenUsedSelections);
        pGuiLanguages = new QWidget();
        pGuiLanguages->setObjectName("pGuiLanguages");
        verticalLayout_52 = new QVBoxLayout(pGuiLanguages);
        verticalLayout_52->setObjectName("verticalLayout_52");
        verticalLayout_52->setContentsMargins(0, 0, 0, 0);
        groupBox_27 = new QGroupBox(pGuiLanguages);
        groupBox_27->setObjectName("groupBox_27");
        verticalLayout_49 = new QVBoxLayout(groupBox_27);
        verticalLayout_49->setObjectName("verticalLayout_49");
        gridLayout_11 = new QGridLayout();
        gridLayout_11->setObjectName("gridLayout_11");
        label_26 = new QLabel(groupBox_27);
        label_26->setObjectName("label_26");

        gridLayout_11->addWidget(label_26, 0, 0, 1, 1);

        cbGuiBCP47LanguageEditingMode = new QComboBox(groupBox_27);
        cbGuiBCP47LanguageEditingMode->setObjectName("cbGuiBCP47LanguageEditingMode");

        gridLayout_11->addWidget(cbGuiBCP47LanguageEditingMode, 0, 1, 1, 1);

        label_11 = new QLabel(groupBox_27);
        label_11->setObjectName("label_11");

        gridLayout_11->addWidget(label_11, 1, 0, 1, 1);

        cbGuiBCP47NormalizationMode = new QComboBox(groupBox_27);
        cbGuiBCP47NormalizationMode->setObjectName("cbGuiBCP47NormalizationMode");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cbGuiBCP47NormalizationMode->sizePolicy().hasHeightForWidth());
        cbGuiBCP47NormalizationMode->setSizePolicy(sizePolicy2);

        gridLayout_11->addWidget(cbGuiBCP47NormalizationMode, 1, 1, 1, 1);


        verticalLayout_49->addLayout(gridLayout_11);

        cbUseISO639_3Languages = new QCheckBox(groupBox_27);
        cbUseISO639_3Languages->setObjectName("cbUseISO639_3Languages");

        verticalLayout_49->addWidget(cbUseISO639_3Languages);


        verticalLayout_52->addWidget(groupBox_27);

        groupBox_26 = new QGroupBox(pGuiLanguages);
        groupBox_26->setObjectName("groupBox_26");
        horizontalLayout_18 = new QHBoxLayout(groupBox_26);
        horizontalLayout_18->setObjectName("horizontalLayout_18");
        twGuiLanguageShortcuts = new QTreeWidget(groupBox_26);
        twGuiLanguageShortcuts->setObjectName("twGuiLanguageShortcuts");
        twGuiLanguageShortcuts->setDragEnabled(true);
        twGuiLanguageShortcuts->setDragDropMode(QAbstractItemView::InternalMove);
        twGuiLanguageShortcuts->setDefaultDropAction(Qt::MoveAction);
        twGuiLanguageShortcuts->setSelectionMode(QAbstractItemView::ExtendedSelection);
        twGuiLanguageShortcuts->setSelectionBehavior(QAbstractItemView::SelectRows);
        twGuiLanguageShortcuts->setRootIsDecorated(false);

        horizontalLayout_18->addWidget(twGuiLanguageShortcuts);

        verticalLayout_48 = new QVBoxLayout();
        verticalLayout_48->setObjectName("verticalLayout_48");
        pbGuiAddLanguageShortcut = new QPushButton(groupBox_26);
        pbGuiAddLanguageShortcut->setObjectName("pbGuiAddLanguageShortcut");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(pbGuiAddLanguageShortcut->sizePolicy().hasHeightForWidth());
        pbGuiAddLanguageShortcut->setSizePolicy(sizePolicy3);
        pbGuiAddLanguageShortcut->setText(QString::fromUtf8(""));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        pbGuiAddLanguageShortcut->setIcon(icon);

        verticalLayout_48->addWidget(pbGuiAddLanguageShortcut);

        pbGuiEditLanguageShortcut = new QPushButton(groupBox_26);
        pbGuiEditLanguageShortcut->setObjectName("pbGuiEditLanguageShortcut");
        sizePolicy3.setHeightForWidth(pbGuiEditLanguageShortcut->sizePolicy().hasHeightForWidth());
        pbGuiEditLanguageShortcut->setSizePolicy(sizePolicy3);
        pbGuiEditLanguageShortcut->setText(QString::fromUtf8(""));
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-entry")));
        pbGuiEditLanguageShortcut->setIcon(icon1);

        verticalLayout_48->addWidget(pbGuiEditLanguageShortcut);

        pbGuiRemoveLanguageShortcuts = new QPushButton(groupBox_26);
        pbGuiRemoveLanguageShortcuts->setObjectName("pbGuiRemoveLanguageShortcuts");
        sizePolicy3.setHeightForWidth(pbGuiRemoveLanguageShortcuts->sizePolicy().hasHeightForWidth());
        pbGuiRemoveLanguageShortcuts->setSizePolicy(sizePolicy3);
        pbGuiRemoveLanguageShortcuts->setText(QString::fromUtf8(""));
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        pbGuiRemoveLanguageShortcuts->setIcon(icon2);

        verticalLayout_48->addWidget(pbGuiRemoveLanguageShortcuts);

        verticalSpacer_3 = new QSpacerItem(0, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_48->addItem(verticalSpacer_3);


        horizontalLayout_18->addLayout(verticalLayout_48);


        verticalLayout_52->addWidget(groupBox_26);

        pages->addWidget(pGuiLanguages);
        pMergeGeneral = new QWidget();
        pMergeGeneral->setObjectName("pMergeGeneral");
        verticalLayout_45 = new QVBoxLayout(pMergeGeneral);
        verticalLayout_45->setObjectName("verticalLayout_45");
        verticalLayout_45->setContentsMargins(0, 0, 0, 0);
        groupBox_3 = new QGroupBox(pMergeGeneral);
        groupBox_3->setObjectName("groupBox_3");
        verticalLayout_4 = new QVBoxLayout(groupBox_3);
        verticalLayout_4->setObjectName("verticalLayout_4");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        leMMediaInfoExe = new QLineEdit(groupBox_3);
        leMMediaInfoExe->setObjectName("leMMediaInfoExe");

        horizontalLayout_16->addWidget(leMMediaInfoExe);

        pbMBrowseMediaInfoExe = new QPushButton(groupBox_3);
        pbMBrowseMediaInfoExe->setObjectName("pbMBrowseMediaInfoExe");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("document-open-folder")));
        pbMBrowseMediaInfoExe->setIcon(icon3);

        horizontalLayout_16->addWidget(pbMBrowseMediaInfoExe);


        gridLayout_2->addLayout(horizontalLayout_16, 5, 1, 1, 1);

        cbMProcessPriority = new QComboBox(groupBox_3);
        cbMProcessPriority->setObjectName("cbMProcessPriority");
        sizePolicy1.setHeightForWidth(cbMProcessPriority->sizePolicy().hasHeightForWidth());
        cbMProcessPriority->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(cbMProcessPriority, 2, 1, 1, 1);

        label_19 = new QLabel(groupBox_3);
        label_19->setObjectName("label_19");

        gridLayout_2->addWidget(label_19, 1, 0, 1, 1);

        label_16 = new QLabel(groupBox_3);
        label_16->setObjectName("label_16");

        gridLayout_2->addWidget(label_16, 3, 0, 1, 1);

        cbMWarnMissingAudioTrack = new QComboBox(groupBox_3);
        cbMWarnMissingAudioTrack->setObjectName("cbMWarnMissingAudioTrack");

        gridLayout_2->addWidget(cbMWarnMissingAudioTrack, 1, 1, 1, 1);

        label_6 = new QLabel(groupBox_3);
        label_6->setObjectName("label_6");

        gridLayout_2->addWidget(label_6, 0, 0, 1, 1);

        cbMClearMergeSettings = new QComboBox(groupBox_3);
        cbMClearMergeSettings->addItem(QString());
        cbMClearMergeSettings->addItem(QString());
        cbMClearMergeSettings->addItem(QString());
        cbMClearMergeSettings->addItem(QString());
        cbMClearMergeSettings->setObjectName("cbMClearMergeSettings");
        sizePolicy1.setHeightForWidth(cbMClearMergeSettings->sizePolicy().hasHeightForWidth());
        cbMClearMergeSettings->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(cbMClearMergeSettings, 0, 1, 1, 1);

        cbMProbeRangePercentage = new QDoubleSpinBox(groupBox_3);
        cbMProbeRangePercentage->setObjectName("cbMProbeRangePercentage");
        cbMProbeRangePercentage->setMinimum(0.010000000000000);
        cbMProbeRangePercentage->setSingleStep(0.100000000000000);
        cbMProbeRangePercentage->setValue(0.300000000000000);

        gridLayout_2->addWidget(cbMProbeRangePercentage, 3, 1, 1, 1);

        label_20 = new QLabel(groupBox_3);
        label_20->setObjectName("label_20");

        gridLayout_2->addWidget(label_20, 5, 0, 1, 1);

        label_5 = new QLabel(groupBox_3);
        label_5->setObjectName("label_5");

        gridLayout_2->addWidget(label_5, 2, 0, 1, 1);

        cbMDefaultCommandLineEscapeMode = new QComboBox(groupBox_3);
        cbMDefaultCommandLineEscapeMode->setObjectName("cbMDefaultCommandLineEscapeMode");

        gridLayout_2->addWidget(cbMDefaultCommandLineEscapeMode, 4, 1, 1, 1);

        label_21 = new QLabel(groupBox_3);
        label_21->setObjectName("label_21");

        gridLayout_2->addWidget(label_21, 4, 0, 1, 1);


        verticalLayout_4->addLayout(gridLayout_2);

        cbMEnsureAtLeastOneTrackEnabled = new QCheckBox(groupBox_3);
        cbMEnsureAtLeastOneTrackEnabled->setObjectName("cbMEnsureAtLeastOneTrackEnabled");

        verticalLayout_4->addWidget(cbMEnsureAtLeastOneTrackEnabled);


        verticalLayout_45->addWidget(groupBox_3);

        groupBox_23 = new QGroupBox(pMergeGeneral);
        groupBox_23->setObjectName("groupBox_23");
        verticalLayout_43 = new QVBoxLayout(groupBox_23);
        verticalLayout_43->setObjectName("verticalLayout_43");
        gridLayout_10 = new QGridLayout();
        gridLayout_10->setObjectName("gridLayout_10");
        label_23 = new QLabel(groupBox_23);
        label_23->setObjectName("label_23");

        gridLayout_10->addWidget(label_23, 1, 0, 1, 1);

        cbMDragAndDropFilesPolicy = new QComboBox(groupBox_23);
        cbMDragAndDropFilesPolicy->setObjectName("cbMDragAndDropFilesPolicy");
        sizePolicy1.setHeightForWidth(cbMDragAndDropFilesPolicy->sizePolicy().hasHeightForWidth());
        cbMDragAndDropFilesPolicy->setSizePolicy(sizePolicy1);

        gridLayout_10->addWidget(cbMDragAndDropFilesPolicy, 1, 1, 1, 1);

        label_13 = new QLabel(groupBox_23);
        label_13->setObjectName("label_13");

        gridLayout_10->addWidget(label_13, 0, 0, 1, 1);

        cbMAddingAppendingFilesPolicy = new QComboBox(groupBox_23);
        cbMAddingAppendingFilesPolicy->setObjectName("cbMAddingAppendingFilesPolicy");
        sizePolicy1.setHeightForWidth(cbMAddingAppendingFilesPolicy->sizePolicy().hasHeightForWidth());
        cbMAddingAppendingFilesPolicy->setSizePolicy(sizePolicy1);

        gridLayout_10->addWidget(cbMAddingAppendingFilesPolicy, 0, 1, 1, 1);

        label_25 = new QLabel(groupBox_23);
        label_25->setObjectName("label_25");

        gridLayout_10->addWidget(label_25, 2, 0, 1, 1);

        cbMDragAndDropDirectoriesPolicy = new QComboBox(groupBox_23);
        cbMDragAndDropDirectoriesPolicy->setObjectName("cbMDragAndDropDirectoriesPolicy");
        sizePolicy1.setHeightForWidth(cbMDragAndDropDirectoriesPolicy->sizePolicy().hasHeightForWidth());
        cbMDragAndDropDirectoriesPolicy->setSizePolicy(sizePolicy1);

        gridLayout_10->addWidget(cbMDragAndDropDirectoriesPolicy, 2, 1, 1, 1);


        verticalLayout_43->addLayout(gridLayout_10);

        cbMAlwaysCreateSettingsForVideoFiles = new QCheckBox(groupBox_23);
        cbMAlwaysCreateSettingsForVideoFiles->setObjectName("cbMAlwaysCreateSettingsForVideoFiles");

        verticalLayout_43->addWidget(cbMAlwaysCreateSettingsForVideoFiles);

        cbMShowDNDZones = new QCheckBox(groupBox_23);
        cbMShowDNDZones->setObjectName("cbMShowDNDZones");

        verticalLayout_43->addWidget(cbMShowDNDZones);

        cbMSortFilesTracksByTypeWhenAdding = new QCheckBox(groupBox_23);
        cbMSortFilesTracksByTypeWhenAdding->setObjectName("cbMSortFilesTracksByTypeWhenAdding");

        verticalLayout_43->addWidget(cbMSortFilesTracksByTypeWhenAdding);

        cbMReconstructSequencesWhenAdding = new QCheckBox(groupBox_23);
        cbMReconstructSequencesWhenAdding->setObjectName("cbMReconstructSequencesWhenAdding");

        verticalLayout_43->addWidget(cbMReconstructSequencesWhenAdding);


        verticalLayout_45->addWidget(groupBox_23);

        groupBox_25 = new QGroupBox(pMergeGeneral);
        groupBox_25->setObjectName("groupBox_25");
        verticalLayout_47 = new QVBoxLayout(groupBox_25);
        verticalLayout_47->setObjectName("verticalLayout_47");
        cbMAttachmentAlwaysSkipForExistingName = new QCheckBox(groupBox_25);
        cbMAttachmentAlwaysSkipForExistingName->setObjectName("cbMAttachmentAlwaysSkipForExistingName");

        verticalLayout_47->addWidget(cbMAttachmentAlwaysSkipForExistingName);


        verticalLayout_45->addWidget(groupBox_25);

        verticalSpacer_12 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_45->addItem(verticalSpacer_12);

        pages->addWidget(pMergeGeneral);
        pMergeLayout = new QWidget();
        pMergeLayout->setObjectName("pMergeLayout");
        verticalLayout_53 = new QVBoxLayout(pMergeLayout);
        verticalLayout_53->setSpacing(0);
        verticalLayout_53->setObjectName("verticalLayout_53");
        verticalLayout_53->setContentsMargins(0, 0, 0, 0);
        groupBox_12 = new QGroupBox(pMergeLayout);
        groupBox_12->setObjectName("groupBox_12");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(groupBox_12->sizePolicy().hasHeightForWidth());
        groupBox_12->setSizePolicy(sizePolicy4);
        verticalLayout_20 = new QVBoxLayout(groupBox_12);
        verticalLayout_20->setObjectName("verticalLayout_20");
        cbMAlwaysShowOutputFileControls = new QCheckBox(groupBox_12);
        cbMAlwaysShowOutputFileControls->setObjectName("cbMAlwaysShowOutputFileControls");

        verticalLayout_20->addWidget(cbMAlwaysShowOutputFileControls);

        cbMTrackPropertiesLayoutLabel = new QLabel(groupBox_12);
        cbMTrackPropertiesLayoutLabel->setObjectName("cbMTrackPropertiesLayoutLabel");

        verticalLayout_20->addWidget(cbMTrackPropertiesLayoutLabel);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        horizontalSpacer_8 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_8);

        verticalLayout_12 = new QVBoxLayout();
        verticalLayout_12->setObjectName("verticalLayout_12");
        rbMTrackPropertiesLayoutHorizontalScrollArea = new QRadioButton(groupBox_12);
        rbMTrackPropertiesLayoutHorizontalScrollArea->setObjectName("rbMTrackPropertiesLayoutHorizontalScrollArea");

        verticalLayout_12->addWidget(rbMTrackPropertiesLayoutHorizontalScrollArea);

        rbMTrackPropertiesLayoutHorizontalTwoColumns = new QRadioButton(groupBox_12);
        rbMTrackPropertiesLayoutHorizontalTwoColumns->setObjectName("rbMTrackPropertiesLayoutHorizontalTwoColumns");

        verticalLayout_12->addWidget(rbMTrackPropertiesLayoutHorizontalTwoColumns);

        rbMTrackPropertiesLayoutVerticalTabWidget = new QRadioButton(groupBox_12);
        rbMTrackPropertiesLayoutVerticalTabWidget->setObjectName("rbMTrackPropertiesLayoutVerticalTabWidget");

        verticalLayout_12->addWidget(rbMTrackPropertiesLayoutVerticalTabWidget);


        horizontalLayout_8->addLayout(verticalLayout_12);


        verticalLayout_20->addLayout(horizontalLayout_8);


        verticalLayout_53->addWidget(groupBox_12);

        groupBox_24 = new QGroupBox(pMergeLayout);
        groupBox_24->setObjectName("groupBox_24");
        verticalLayout_46 = new QVBoxLayout(groupBox_24);
        verticalLayout_46->setObjectName("verticalLayout_46");
        cbMUseFileAndTrackColors = new QCheckBox(groupBox_24);
        cbMUseFileAndTrackColors->setObjectName("cbMUseFileAndTrackColors");

        verticalLayout_46->addWidget(cbMUseFileAndTrackColors);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        lwMFileColors = new QListWidget(groupBox_24);
        lwMFileColors->setObjectName("lwMFileColors");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(lwMFileColors->sizePolicy().hasHeightForWidth());
        lwMFileColors->setSizePolicy(sizePolicy5);
        lwMFileColors->setMinimumSize(QSize(100, 0));
        lwMFileColors->setMaximumSize(QSize(200, 16777215));
        lwMFileColors->setEditTriggers(QAbstractItemView::NoEditTriggers);
        lwMFileColors->setDragEnabled(true);
        lwMFileColors->setDragDropMode(QAbstractItemView::InternalMove);
        lwMFileColors->setDefaultDropAction(Qt::MoveAction);
        lwMFileColors->setSelectionMode(QAbstractItemView::ExtendedSelection);

        horizontalLayout_3->addWidget(lwMFileColors);

        verticalLayout_37 = new QVBoxLayout();
        verticalLayout_37->setObjectName("verticalLayout_37");
        pbMAddFileColor = new QPushButton(groupBox_24);
        pbMAddFileColor->setObjectName("pbMAddFileColor");
        pbMAddFileColor->setText(QString::fromUtf8(""));
        pbMAddFileColor->setIcon(icon);

        verticalLayout_37->addWidget(pbMAddFileColor);

        pbMRemoveFileColors = new QPushButton(groupBox_24);
        pbMRemoveFileColors->setObjectName("pbMRemoveFileColors");
        pbMRemoveFileColors->setText(QString::fromUtf8(""));
        pbMRemoveFileColors->setIcon(icon2);

        verticalLayout_37->addWidget(pbMRemoveFileColors);

        pbMEditFileColor = new QPushButton(groupBox_24);
        pbMEditFileColor->setObjectName("pbMEditFileColor");
        pbMEditFileColor->setText(QString::fromUtf8(""));
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("document-edit")));
        pbMEditFileColor->setIcon(icon4);

        verticalLayout_37->addWidget(pbMEditFileColor);

        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_37->addItem(verticalSpacer);

        pbMRevertFileColorsToDefault = new QPushButton(groupBox_24);
        pbMRevertFileColorsToDefault->setObjectName("pbMRevertFileColorsToDefault");
        pbMRevertFileColorsToDefault->setText(QString::fromUtf8(""));
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("document-revert")));
        pbMRevertFileColorsToDefault->setIcon(icon5);

        verticalLayout_37->addWidget(pbMRevertFileColorsToDefault);

        verticalSpacer_7 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        verticalLayout_37->addItem(verticalSpacer_7);


        horizontalLayout_3->addLayout(verticalLayout_37);

        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_11);


        verticalLayout_46->addLayout(horizontalLayout_3);


        verticalLayout_53->addWidget(groupBox_24);

        verticalSpacer_13 = new QSpacerItem(20, 276, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_53->addItem(verticalSpacer_13);

        pages->addWidget(pMergeLayout);
        pMergePredefinedValues = new QWidget();
        pMergePredefinedValues->setObjectName("pMergePredefinedValues");
        verticalLayout_39 = new QVBoxLayout(pMergePredefinedValues);
        verticalLayout_39->setObjectName("verticalLayout_39");
        verticalLayout_39->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        gpMPredefinedVideoTrackNames = new QGroupBox(pMergePredefinedValues);
        gpMPredefinedVideoTrackNames->setObjectName("gpMPredefinedVideoTrackNames");
        verticalLayout_50 = new QVBoxLayout(gpMPredefinedVideoTrackNames);
        verticalLayout_50->setObjectName("verticalLayout_50");
        lwMPredefinedVideoTrackNames = new mtx::gui::Util::StringListConfigurationWidget(gpMPredefinedVideoTrackNames);
        lwMPredefinedVideoTrackNames->setObjectName("lwMPredefinedVideoTrackNames");

        verticalLayout_50->addWidget(lwMPredefinedVideoTrackNames);


        horizontalLayout_15->addWidget(gpMPredefinedVideoTrackNames);

        gpMPredefinedAudioTrackNames = new QGroupBox(pMergePredefinedValues);
        gpMPredefinedAudioTrackNames->setObjectName("gpMPredefinedAudioTrackNames");
        verticalLayout_51 = new QVBoxLayout(gpMPredefinedAudioTrackNames);
        verticalLayout_51->setObjectName("verticalLayout_51");
        lwMPredefinedAudioTrackNames = new mtx::gui::Util::StringListConfigurationWidget(gpMPredefinedAudioTrackNames);
        lwMPredefinedAudioTrackNames->setObjectName("lwMPredefinedAudioTrackNames");

        verticalLayout_51->addWidget(lwMPredefinedAudioTrackNames);


        horizontalLayout_15->addWidget(gpMPredefinedAudioTrackNames);

        gpMPredefinedSubtitleTrackNames = new QGroupBox(pMergePredefinedValues);
        gpMPredefinedSubtitleTrackNames->setObjectName("gpMPredefinedSubtitleTrackNames");
        verticalLayout_21 = new QVBoxLayout(gpMPredefinedSubtitleTrackNames);
        verticalLayout_21->setObjectName("verticalLayout_21");
        lwMPredefinedSubtitleTrackNames = new mtx::gui::Util::StringListConfigurationWidget(gpMPredefinedSubtitleTrackNames);
        lwMPredefinedSubtitleTrackNames->setObjectName("lwMPredefinedSubtitleTrackNames");

        verticalLayout_21->addWidget(lwMPredefinedSubtitleTrackNames);


        horizontalLayout_15->addWidget(gpMPredefinedSubtitleTrackNames);


        verticalLayout_39->addLayout(horizontalLayout_15);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        gbMPredefinedSplitSizes = new QGroupBox(pMergePredefinedValues);
        gbMPredefinedSplitSizes->setObjectName("gbMPredefinedSplitSizes");
        verticalLayout_22 = new QVBoxLayout(gbMPredefinedSplitSizes);
        verticalLayout_22->setObjectName("verticalLayout_22");
        lwMPredefinedSplitSizes = new mtx::gui::Util::StringListConfigurationWidget(gbMPredefinedSplitSizes);
        lwMPredefinedSplitSizes->setObjectName("lwMPredefinedSplitSizes");

        verticalLayout_22->addWidget(lwMPredefinedSplitSizes);


        horizontalLayout_14->addWidget(gbMPredefinedSplitSizes);

        gbMPredefinedSplitDurations = new QGroupBox(pMergePredefinedValues);
        gbMPredefinedSplitDurations->setObjectName("gbMPredefinedSplitDurations");
        verticalLayout_38 = new QVBoxLayout(gbMPredefinedSplitDurations);
        verticalLayout_38->setObjectName("verticalLayout_38");
        lwMPredefinedSplitDurations = new mtx::gui::Util::StringListConfigurationWidget(gbMPredefinedSplitDurations);
        lwMPredefinedSplitDurations->setObjectName("lwMPredefinedSplitDurations");

        verticalLayout_38->addWidget(lwMPredefinedSplitDurations);


        horizontalLayout_14->addWidget(gbMPredefinedSplitDurations);


        verticalLayout_39->addLayout(horizontalLayout_14);

        pages->addWidget(pMergePredefinedValues);
        pMergeDefaultsForTracks = new QWidget();
        pMergeDefaultsForTracks->setObjectName("pMergeDefaultsForTracks");
        verticalLayout_23 = new QVBoxLayout(pMergeDefaultsForTracks);
        verticalLayout_23->setObjectName("verticalLayout_23");
        groupBox_11 = new QGroupBox(pMergeDefaultsForTracks);
        groupBox_11->setObjectName("groupBox_11");
        gridLayout_6 = new QGridLayout(groupBox_11);
        gridLayout_6->setObjectName("gridLayout_6");
        label_15 = new QLabel(groupBox_11);
        label_15->setObjectName("label_15");

        gridLayout_6->addWidget(label_15, 0, 0, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        leMDefaultAdditionalCommandLineOptions = new QLineEdit(groupBox_11);
        leMDefaultAdditionalCommandLineOptions->setObjectName("leMDefaultAdditionalCommandLineOptions");
        leMDefaultAdditionalCommandLineOptions->setClearButtonEnabled(true);

        horizontalLayout_9->addWidget(leMDefaultAdditionalCommandLineOptions);

        pbMEditDefaultAdditionalCommandLineOptions = new QPushButton(groupBox_11);
        pbMEditDefaultAdditionalCommandLineOptions->setObjectName("pbMEditDefaultAdditionalCommandLineOptions");
        QIcon icon6(QIcon::fromTheme(QString::fromUtf8("view-choose")));
        pbMEditDefaultAdditionalCommandLineOptions->setIcon(icon6);

        horizontalLayout_9->addWidget(pbMEditDefaultAdditionalCommandLineOptions);


        gridLayout_6->addLayout(horizontalLayout_9, 0, 1, 1, 1);


        verticalLayout_23->addWidget(groupBox_11);

        groupBox_10 = new QGroupBox(pMergeDefaultsForTracks);
        groupBox_10->setObjectName("groupBox_10");
        verticalLayout_6 = new QVBoxLayout(groupBox_10);
        verticalLayout_6->setObjectName("verticalLayout_6");
        cbMAutoSetFileTitle = new QCheckBox(groupBox_10);
        cbMAutoSetFileTitle->setObjectName("cbMAutoSetFileTitle");

        verticalLayout_6->addWidget(cbMAutoSetFileTitle);

        cbMAutoClearFileTitle = new QCheckBox(groupBox_10);
        cbMAutoClearFileTitle->setObjectName("cbMAutoClearFileTitle");

        verticalLayout_6->addWidget(cbMAutoClearFileTitle);

        cbMSetAudioDelayFromFileName = new QCheckBox(groupBox_10);
        cbMSetAudioDelayFromFileName->setObjectName("cbMSetAudioDelayFromFileName");

        verticalLayout_6->addWidget(cbMSetAudioDelayFromFileName);

        cbMDisableDefaultTrackForSubtitles = new QCheckBox(groupBox_10);
        cbMDisableDefaultTrackForSubtitles->setObjectName("cbMDisableDefaultTrackForSubtitles");

        verticalLayout_6->addWidget(cbMDisableDefaultTrackForSubtitles);

        cbMDisableCompressionForAllTrackTypes = new QCheckBox(groupBox_10);
        cbMDisableCompressionForAllTrackTypes->setObjectName("cbMDisableCompressionForAllTrackTypes");

        verticalLayout_6->addWidget(cbMDisableCompressionForAllTrackTypes);

        cbMEnableDialogNormGainRemoval = new QCheckBox(groupBox_10);
        cbMEnableDialogNormGainRemoval->setObjectName("cbMEnableDialogNormGainRemoval");

        verticalLayout_6->addWidget(cbMEnableDialogNormGainRemoval);

        gridLayout_12 = new QGridLayout();
        gridLayout_12->setObjectName("gridLayout_12");
        cbMDeriveForcedDisplayFlagSubtitles = new QCheckBox(groupBox_10);
        cbMDeriveForcedDisplayFlagSubtitles->setObjectName("cbMDeriveForcedDisplayFlagSubtitles");

        gridLayout_12->addWidget(cbMDeriveForcedDisplayFlagSubtitles, 0, 0, 1, 1);

        cbMDefaultSubtitleCharset = new mtx::gui::Util::CharacterSetComboBox(groupBox_10);
        cbMDefaultSubtitleCharset->setObjectName("cbMDefaultSubtitleCharset");
        sizePolicy2.setHeightForWidth(cbMDefaultSubtitleCharset->sizePolicy().hasHeightForWidth());
        cbMDefaultSubtitleCharset->setSizePolicy(sizePolicy2);

        gridLayout_12->addWidget(cbMDefaultSubtitleCharset, 5, 1, 1, 1);

        cbMDeriveCommentaryFlag = new QCheckBox(groupBox_10);
        cbMDeriveCommentaryFlag->setObjectName("cbMDeriveCommentaryFlag");

        gridLayout_12->addWidget(cbMDeriveCommentaryFlag, 2, 0, 1, 1);

        ldwMSetOriginalLanguageFlagLanguage = new mtx::gui::Util::LanguageDisplayWidget(groupBox_10);
        ldwMSetOriginalLanguageFlagLanguage->setObjectName("ldwMSetOriginalLanguageFlagLanguage");
        sizePolicy2.setHeightForWidth(ldwMSetOriginalLanguageFlagLanguage->sizePolicy().hasHeightForWidth());
        ldwMSetOriginalLanguageFlagLanguage->setSizePolicy(sizePolicy2);
        ldwMSetOriginalLanguageFlagLanguage->setMinimumSize(QSize(0, 20));

        gridLayout_12->addWidget(ldwMSetOriginalLanguageFlagLanguage, 4, 1, 1, 1);

        cbMSetOriginalLanguageFlagLanguage = new QCheckBox(groupBox_10);
        cbMSetOriginalLanguageFlagLanguage->setObjectName("cbMSetOriginalLanguageFlagLanguage");

        gridLayout_12->addWidget(cbMSetOriginalLanguageFlagLanguage, 4, 0, 1, 1);

        horizontalLayout_19 = new QHBoxLayout();
        horizontalLayout_19->setObjectName("horizontalLayout_19");
        leMDeriveCommentaryFlagRE = new QLineEdit(groupBox_10);
        leMDeriveCommentaryFlagRE->setObjectName("leMDeriveCommentaryFlagRE");

        horizontalLayout_19->addWidget(leMDeriveCommentaryFlagRE);

        pbMDeriveCommentaryFlagRERevert = new QPushButton(groupBox_10);
        pbMDeriveCommentaryFlagRERevert->setObjectName("pbMDeriveCommentaryFlagRERevert");
        pbMDeriveCommentaryFlagRERevert->setText(QString::fromUtf8(""));
        QIcon icon7(QIcon::fromTheme(QString::fromUtf8("edit-undo")));
        pbMDeriveCommentaryFlagRERevert->setIcon(icon7);

        horizontalLayout_19->addWidget(pbMDeriveCommentaryFlagRERevert);


        gridLayout_12->addLayout(horizontalLayout_19, 2, 1, 1, 1);

        cbMDeriveHearingImpairedFlag = new QCheckBox(groupBox_10);
        cbMDeriveHearingImpairedFlag->setObjectName("cbMDeriveHearingImpairedFlag");

        gridLayout_12->addWidget(cbMDeriveHearingImpairedFlag, 1, 0, 1, 1);

        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        leMDeriveHearingImpairedFlagRE = new QLineEdit(groupBox_10);
        leMDeriveHearingImpairedFlagRE->setObjectName("leMDeriveHearingImpairedFlagRE");

        horizontalLayout_17->addWidget(leMDeriveHearingImpairedFlagRE);

        pbMDeriveHearingImpairedFlagRERevert = new QPushButton(groupBox_10);
        pbMDeriveHearingImpairedFlagRERevert->setObjectName("pbMDeriveHearingImpairedFlagRERevert");
        pbMDeriveHearingImpairedFlagRERevert->setText(QString::fromUtf8(""));
        pbMDeriveHearingImpairedFlagRERevert->setIcon(icon7);

        horizontalLayout_17->addWidget(pbMDeriveHearingImpairedFlagRERevert);


        gridLayout_12->addLayout(horizontalLayout_17, 1, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        leMDeriveForcedDisplayFlagSubtitlesRE = new QLineEdit(groupBox_10);
        leMDeriveForcedDisplayFlagSubtitlesRE->setObjectName("leMDeriveForcedDisplayFlagSubtitlesRE");

        horizontalLayout->addWidget(leMDeriveForcedDisplayFlagSubtitlesRE);

        pbMDeriveForcedDisplayFlagSubtitlesRERevert = new QPushButton(groupBox_10);
        pbMDeriveForcedDisplayFlagSubtitlesRERevert->setObjectName("pbMDeriveForcedDisplayFlagSubtitlesRERevert");
        pbMDeriveForcedDisplayFlagSubtitlesRERevert->setText(QString::fromUtf8(""));
        pbMDeriveForcedDisplayFlagSubtitlesRERevert->setIcon(icon7);

        horizontalLayout->addWidget(pbMDeriveForcedDisplayFlagSubtitlesRERevert);


        gridLayout_12->addLayout(horizontalLayout, 0, 1, 1, 1);

        label_4 = new QLabel(groupBox_10);
        label_4->setObjectName("label_4");

        gridLayout_12->addWidget(label_4, 5, 0, 1, 1);


        verticalLayout_6->addLayout(gridLayout_12);

        cbMDeriveFlagsFromTrackNames = new QCheckBox(groupBox_10);
        cbMDeriveFlagsFromTrackNames->setObjectName("cbMDeriveFlagsFromTrackNames");

        verticalLayout_6->addWidget(cbMDeriveFlagsFromTrackNames);

        groupBox_9 = new QGroupBox(groupBox_10);
        groupBox_9->setObjectName("groupBox_9");
        gridLayout_5 = new QGridLayout(groupBox_9);
        gridLayout_5->setObjectName("gridLayout_5");
        lDefaultAudioTrackLanguage = new QLabel(groupBox_9);
        lDefaultAudioTrackLanguage->setObjectName("lDefaultAudioTrackLanguage");

        gridLayout_5->addWidget(lDefaultAudioTrackLanguage, 0, 0, 1, 1);

        ldwMDefaultAudioTrackLanguage = new mtx::gui::Util::LanguageDisplayWidget(groupBox_9);
        ldwMDefaultAudioTrackLanguage->setObjectName("ldwMDefaultAudioTrackLanguage");
        sizePolicy2.setHeightForWidth(ldwMDefaultAudioTrackLanguage->sizePolicy().hasHeightForWidth());
        ldwMDefaultAudioTrackLanguage->setSizePolicy(sizePolicy2);

        gridLayout_5->addWidget(ldwMDefaultAudioTrackLanguage, 0, 1, 1, 1);

        ldwMDefaultSubtitleTrackLanguage = new mtx::gui::Util::LanguageDisplayWidget(groupBox_9);
        ldwMDefaultSubtitleTrackLanguage->setObjectName("ldwMDefaultSubtitleTrackLanguage");
        sizePolicy2.setHeightForWidth(ldwMDefaultSubtitleTrackLanguage->sizePolicy().hasHeightForWidth());
        ldwMDefaultSubtitleTrackLanguage->setSizePolicy(sizePolicy2);

        gridLayout_5->addWidget(ldwMDefaultSubtitleTrackLanguage, 2, 1, 1, 1);

        ldwMDefaultVideoTrackLanguage = new mtx::gui::Util::LanguageDisplayWidget(groupBox_9);
        ldwMDefaultVideoTrackLanguage->setObjectName("ldwMDefaultVideoTrackLanguage");
        sizePolicy2.setHeightForWidth(ldwMDefaultVideoTrackLanguage->sizePolicy().hasHeightForWidth());
        ldwMDefaultVideoTrackLanguage->setSizePolicy(sizePolicy2);

        gridLayout_5->addWidget(ldwMDefaultVideoTrackLanguage, 1, 1, 1, 1);

        lDefaultVideoTrackLanguage = new QLabel(groupBox_9);
        lDefaultVideoTrackLanguage->setObjectName("lDefaultVideoTrackLanguage");

        gridLayout_5->addWidget(lDefaultVideoTrackLanguage, 1, 0, 1, 1);

        lDefaultSubtitleTrackLanguage = new QLabel(groupBox_9);
        lDefaultSubtitleTrackLanguage->setObjectName("lDefaultSubtitleTrackLanguage");

        gridLayout_5->addWidget(lDefaultSubtitleTrackLanguage, 2, 0, 1, 1);

        lWhenToSetDefaultLanguage = new QLabel(groupBox_9);
        lWhenToSetDefaultLanguage->setObjectName("lWhenToSetDefaultLanguage");

        gridLayout_5->addWidget(lWhenToSetDefaultLanguage, 3, 0, 1, 1);

        cbMWhenToSetDefaultLanguage = new QComboBox(groupBox_9);
        cbMWhenToSetDefaultLanguage->setObjectName("cbMWhenToSetDefaultLanguage");

        gridLayout_5->addWidget(cbMWhenToSetDefaultLanguage, 3, 1, 1, 1);


        verticalLayout_6->addWidget(groupBox_9);


        verticalLayout_23->addWidget(groupBox_10);

        verticalSpacer_8 = new QSpacerItem(20, 46, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_23->addItem(verticalSpacer_8);

        pages->addWidget(pMergeDefaultsForTracks);
        pMergeDerivingTrackLanguageFromFileName = new QWidget();
        pMergeDerivingTrackLanguageFromFileName->setObjectName("pMergeDerivingTrackLanguageFromFileName");
        verticalLayout_35 = new QVBoxLayout(pMergeDerivingTrackLanguageFromFileName);
        verticalLayout_35->setObjectName("verticalLayout_35");
        verticalLayout_35->setContentsMargins(0, 0, 0, 0);
        groupBox_18 = new QGroupBox(pMergeDerivingTrackLanguageFromFileName);
        groupBox_18->setObjectName("groupBox_18");
        gridLayout_8 = new QGridLayout(groupBox_18);
        gridLayout_8->setObjectName("gridLayout_8");
        lDeriveAudioTrackLanguageFromFileName = new QLabel(groupBox_18);
        lDeriveAudioTrackLanguageFromFileName->setObjectName("lDeriveAudioTrackLanguageFromFileName");

        gridLayout_8->addWidget(lDeriveAudioTrackLanguageFromFileName, 0, 0, 1, 1);

        cbMDeriveAudioTrackLanguageFromFileName = new QComboBox(groupBox_18);
        cbMDeriveAudioTrackLanguageFromFileName->setObjectName("cbMDeriveAudioTrackLanguageFromFileName");
        sizePolicy2.setHeightForWidth(cbMDeriveAudioTrackLanguageFromFileName->sizePolicy().hasHeightForWidth());
        cbMDeriveAudioTrackLanguageFromFileName->setSizePolicy(sizePolicy2);

        gridLayout_8->addWidget(cbMDeriveAudioTrackLanguageFromFileName, 0, 1, 1, 1);

        lDeriveVideoTrackLanguageFromFileName = new QLabel(groupBox_18);
        lDeriveVideoTrackLanguageFromFileName->setObjectName("lDeriveVideoTrackLanguageFromFileName");

        gridLayout_8->addWidget(lDeriveVideoTrackLanguageFromFileName, 1, 0, 1, 1);

        cbMDeriveVideoTrackLanguageFromFileName = new QComboBox(groupBox_18);
        cbMDeriveVideoTrackLanguageFromFileName->setObjectName("cbMDeriveVideoTrackLanguageFromFileName");
        sizePolicy2.setHeightForWidth(cbMDeriveVideoTrackLanguageFromFileName->sizePolicy().hasHeightForWidth());
        cbMDeriveVideoTrackLanguageFromFileName->setSizePolicy(sizePolicy2);

        gridLayout_8->addWidget(cbMDeriveVideoTrackLanguageFromFileName, 1, 1, 1, 1);

        lDeriveSubtitleTrackLanguageFromFileName = new QLabel(groupBox_18);
        lDeriveSubtitleTrackLanguageFromFileName->setObjectName("lDeriveSubtitleTrackLanguageFromFileName");

        gridLayout_8->addWidget(lDeriveSubtitleTrackLanguageFromFileName, 2, 0, 1, 1);

        cbMDeriveSubtitleTrackLanguageFromFileName = new QComboBox(groupBox_18);
        cbMDeriveSubtitleTrackLanguageFromFileName->setObjectName("cbMDeriveSubtitleTrackLanguageFromFileName");
        sizePolicy2.setHeightForWidth(cbMDeriveSubtitleTrackLanguageFromFileName->sizePolicy().hasHeightForWidth());
        cbMDeriveSubtitleTrackLanguageFromFileName->setSizePolicy(sizePolicy2);

        gridLayout_8->addWidget(cbMDeriveSubtitleTrackLanguageFromFileName, 2, 1, 1, 1);

        label_18 = new QLabel(groupBox_18);
        label_18->setObjectName("label_18");

        gridLayout_8->addWidget(label_18, 3, 0, 1, 1);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        leMDeriveTrackLanguageBoundaryChars = new QLineEdit(groupBox_18);
        leMDeriveTrackLanguageBoundaryChars->setObjectName("leMDeriveTrackLanguageBoundaryChars");
        leMDeriveTrackLanguageBoundaryChars->setClearButtonEnabled(true);

        horizontalLayout_13->addWidget(leMDeriveTrackLanguageBoundaryChars);

        pbMDeriveTrackLanguageRevertBoundaryChars = new QPushButton(groupBox_18);
        pbMDeriveTrackLanguageRevertBoundaryChars->setObjectName("pbMDeriveTrackLanguageRevertBoundaryChars");
        pbMDeriveTrackLanguageRevertBoundaryChars->setText(QString::fromUtf8(""));
        pbMDeriveTrackLanguageRevertBoundaryChars->setIcon(icon7);

        horizontalLayout_13->addWidget(pbMDeriveTrackLanguageRevertBoundaryChars);


        gridLayout_8->addLayout(horizontalLayout_13, 3, 1, 1, 1);


        verticalLayout_35->addWidget(groupBox_18);

        groupBox_19 = new QGroupBox(pMergeDerivingTrackLanguageFromFileName);
        groupBox_19->setObjectName("groupBox_19");
        verticalLayout_36 = new QVBoxLayout(groupBox_19);
        verticalLayout_36->setObjectName("verticalLayout_36");
        tbMDeriveTrackLanguageRecognizedLanguages = new mtx::gui::Util::SideBySideMultiSelect(groupBox_19);
        tbMDeriveTrackLanguageRecognizedLanguages->setObjectName("tbMDeriveTrackLanguageRecognizedLanguages");
        tbMDeriveTrackLanguageRecognizedLanguages->setFocusPolicy(Qt::StrongFocus);

        verticalLayout_36->addWidget(tbMDeriveTrackLanguageRecognizedLanguages);


        verticalLayout_35->addWidget(groupBox_19);

        verticalLayout_35->setStretch(1, 1);
        pages->addWidget(pMergeDerivingTrackLanguageFromFileName);
        pMergeOutput = new QWidget();
        pMergeOutput->setObjectName("pMergeOutput");
        verticalLayout_7 = new QVBoxLayout(pMergeOutput);
        verticalLayout_7->setObjectName("verticalLayout_7");
        verticalLayout_7->setContentsMargins(0, 0, 0, 0);
        groupBox_5 = new QGroupBox(pMergeOutput);
        groupBox_5->setObjectName("groupBox_5");
        verticalLayout_5 = new QVBoxLayout(groupBox_5);
        verticalLayout_5->setObjectName("verticalLayout_5");
        cbMAutoSetDestinationFileName = new QCheckBox(groupBox_5);
        cbMAutoSetDestinationFileName->setObjectName("cbMAutoSetDestinationFileName");

        verticalLayout_5->addWidget(cbMAutoSetDestinationFileName);

        cbMAutoSetDestinationOnlyForVideoFiles = new QCheckBox(groupBox_5);
        cbMAutoSetDestinationOnlyForVideoFiles->setObjectName("cbMAutoSetDestinationOnlyForVideoFiles");

        verticalLayout_5->addWidget(cbMAutoSetDestinationOnlyForVideoFiles);

        cbMAutoSetDestinationFromTitle = new QCheckBox(groupBox_5);
        cbMAutoSetDestinationFromTitle->setObjectName("cbMAutoSetDestinationFromTitle");

        verticalLayout_5->addWidget(cbMAutoSetDestinationFromTitle);

        cbMAutoSetDestinationFromDirectory = new QCheckBox(groupBox_5);
        cbMAutoSetDestinationFromDirectory->setObjectName("cbMAutoSetDestinationFromDirectory");

        verticalLayout_5->addWidget(cbMAutoSetDestinationFromDirectory);

        gbMAutoSetDestinationDirectory = new QGroupBox(groupBox_5);
        gbMAutoSetDestinationDirectory->setObjectName("gbMAutoSetDestinationDirectory");
        verticalLayout_31 = new QVBoxLayout(gbMAutoSetDestinationDirectory);
        verticalLayout_31->setObjectName("verticalLayout_31");
        rbMAutoSetDestinationSameDirectory = new QRadioButton(gbMAutoSetDestinationDirectory);
        rbMAutoSetDestinationSameDirectory->setObjectName("rbMAutoSetDestinationSameDirectory");

        verticalLayout_31->addWidget(rbMAutoSetDestinationSameDirectory);

        rbMAutoSetDestinationPreviousDirectory = new QRadioButton(gbMAutoSetDestinationDirectory);
        rbMAutoSetDestinationPreviousDirectory->setObjectName("rbMAutoSetDestinationPreviousDirectory");

        verticalLayout_31->addWidget(rbMAutoSetDestinationPreviousDirectory);

        rbMAutoSetDestinationRelativeDirectory = new QRadioButton(gbMAutoSetDestinationDirectory);
        rbMAutoSetDestinationRelativeDirectory->setObjectName("rbMAutoSetDestinationRelativeDirectory");

        verticalLayout_31->addWidget(rbMAutoSetDestinationRelativeDirectory);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        horizontalSpacer_4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_4);

        cbMAutoSetDestinationRelativeDirectory = new QComboBox(gbMAutoSetDestinationDirectory);
        cbMAutoSetDestinationRelativeDirectory->setObjectName("cbMAutoSetDestinationRelativeDirectory");
        cbMAutoSetDestinationRelativeDirectory->setEditable(true);

        horizontalLayout_7->addWidget(cbMAutoSetDestinationRelativeDirectory);


        verticalLayout_31->addLayout(horizontalLayout_7);

        rbMAutoSetDestinationFixedDirectory = new QRadioButton(gbMAutoSetDestinationDirectory);
        rbMAutoSetDestinationFixedDirectory->setObjectName("rbMAutoSetDestinationFixedDirectory");

        verticalLayout_31->addWidget(rbMAutoSetDestinationFixedDirectory);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_3);

        cbMAutoSetDestinationFixedDirectory = new QComboBox(gbMAutoSetDestinationDirectory);
        cbMAutoSetDestinationFixedDirectory->setObjectName("cbMAutoSetDestinationFixedDirectory");
        sizePolicy2.setHeightForWidth(cbMAutoSetDestinationFixedDirectory->sizePolicy().hasHeightForWidth());
        cbMAutoSetDestinationFixedDirectory->setSizePolicy(sizePolicy2);
        cbMAutoSetDestinationFixedDirectory->setEditable(true);

        horizontalLayout_5->addWidget(cbMAutoSetDestinationFixedDirectory);

        pbMAutoSetDestinationBrowseFixedDirectory = new QPushButton(gbMAutoSetDestinationDirectory);
        pbMAutoSetDestinationBrowseFixedDirectory->setObjectName("pbMAutoSetDestinationBrowseFixedDirectory");
        pbMAutoSetDestinationBrowseFixedDirectory->setIcon(icon3);

        horizontalLayout_5->addWidget(pbMAutoSetDestinationBrowseFixedDirectory);


        verticalLayout_31->addLayout(horizontalLayout_5);


        verticalLayout_5->addWidget(gbMAutoSetDestinationDirectory);

        cbMUniqueOutputFileNames = new QCheckBox(groupBox_5);
        cbMUniqueOutputFileNames->setObjectName("cbMUniqueOutputFileNames");

        verticalLayout_5->addWidget(cbMUniqueOutputFileNames);

        cbMAutoClearOutputFileName = new QCheckBox(groupBox_5);
        cbMAutoClearOutputFileName->setObjectName("cbMAutoClearOutputFileName");

        verticalLayout_5->addWidget(cbMAutoClearOutputFileName);


        verticalLayout_7->addWidget(groupBox_5);

        groupBox_22 = new QGroupBox(pMergeOutput);
        groupBox_22->setObjectName("groupBox_22");
        verticalLayout_42 = new QVBoxLayout(groupBox_22);
        verticalLayout_42->setObjectName("verticalLayout_42");
        lwMRecentDestinationDirectories = new mtx::gui::Util::StringListConfigurationWidget(groupBox_22);
        lwMRecentDestinationDirectories->setObjectName("lwMRecentDestinationDirectories");

        verticalLayout_42->addWidget(lwMRecentDestinationDirectories);


        verticalLayout_7->addWidget(groupBox_22);

        pages->addWidget(pMergeOutput);
        pMergeEnableTracks = new QWidget();
        pMergeEnableTracks->setObjectName("pMergeEnableTracks");
        verticalLayout_13 = new QVBoxLayout(pMergeEnableTracks);
        verticalLayout_13->setObjectName("verticalLayout_13");
        verticalLayout_13->setContentsMargins(0, 0, 0, 0);
        groupBox_20 = new QGroupBox(pMergeEnableTracks);
        groupBox_20->setObjectName("groupBox_20");
        verticalLayout_34 = new QVBoxLayout(groupBox_20);
        verticalLayout_34->setObjectName("verticalLayout_34");
        tbMEnableMuxingTracksByType = new mtx::gui::Util::SideBySideMultiSelect(groupBox_20);
        tbMEnableMuxingTracksByType->setObjectName("tbMEnableMuxingTracksByType");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(tbMEnableMuxingTracksByType->sizePolicy().hasHeightForWidth());
        tbMEnableMuxingTracksByType->setSizePolicy(sizePolicy6);
        tbMEnableMuxingTracksByType->setMinimumSize(QSize(0, 100));
        tbMEnableMuxingTracksByType->setMaximumSize(QSize(16777215, 140));
        tbMEnableMuxingTracksByType->setFocusPolicy(Qt::StrongFocus);

        verticalLayout_34->addWidget(tbMEnableMuxingTracksByType);


        verticalLayout_13->addWidget(groupBox_20);

        groupBox_7 = new QGroupBox(pMergeEnableTracks);
        groupBox_7->setObjectName("groupBox_7");
        verticalLayout_44 = new QVBoxLayout(groupBox_7);
        verticalLayout_44->setObjectName("verticalLayout_44");
        cbMEnableMuxingTracksByLanguage = new QCheckBox(groupBox_7);
        cbMEnableMuxingTracksByLanguage->setObjectName("cbMEnableMuxingTracksByLanguage");

        verticalLayout_44->addWidget(cbMEnableMuxingTracksByLanguage);

        tbMEnableMuxingTracksByLanguage = new mtx::gui::Util::SideBySideMultiSelect(groupBox_7);
        tbMEnableMuxingTracksByLanguage->setObjectName("tbMEnableMuxingTracksByLanguage");
        QSizePolicy sizePolicy7(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(tbMEnableMuxingTracksByLanguage->sizePolicy().hasHeightForWidth());
        tbMEnableMuxingTracksByLanguage->setSizePolicy(sizePolicy7);
        tbMEnableMuxingTracksByLanguage->setMinimumSize(QSize(0, 150));
        tbMEnableMuxingTracksByLanguage->setFocusPolicy(Qt::StrongFocus);

        verticalLayout_44->addWidget(tbMEnableMuxingTracksByLanguage);


        verticalLayout_13->addWidget(groupBox_7);

        gbMEnableMuxingGeneral = new QGroupBox(pMergeEnableTracks);
        gbMEnableMuxingGeneral->setObjectName("gbMEnableMuxingGeneral");
        verticalLayout_9 = new QVBoxLayout(gbMEnableMuxingGeneral);
        verticalLayout_9->setObjectName("verticalLayout_9");
        lMEnableMuxingAllTracksOfType = new QLabel(gbMEnableMuxingGeneral);
        lMEnableMuxingAllTracksOfType->setObjectName("lMEnableMuxingAllTracksOfType");

        verticalLayout_9->addWidget(lMEnableMuxingAllTracksOfType);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        cbMEnableMuxingAllVideoTracks = new QCheckBox(gbMEnableMuxingGeneral);
        cbMEnableMuxingAllVideoTracks->setObjectName("cbMEnableMuxingAllVideoTracks");

        horizontalLayout_2->addWidget(cbMEnableMuxingAllVideoTracks);

        horizontalSpacer_9 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_9);

        cbMEnableMuxingAllAudioTracks = new QCheckBox(gbMEnableMuxingGeneral);
        cbMEnableMuxingAllAudioTracks->setObjectName("cbMEnableMuxingAllAudioTracks");

        horizontalLayout_2->addWidget(cbMEnableMuxingAllAudioTracks);

        horizontalSpacer_10 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_10);

        cbMEnableMuxingAllSubtitleTracks = new QCheckBox(gbMEnableMuxingGeneral);
        cbMEnableMuxingAllSubtitleTracks->setObjectName("cbMEnableMuxingAllSubtitleTracks");

        horizontalLayout_2->addWidget(cbMEnableMuxingAllSubtitleTracks);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout_9->addLayout(horizontalLayout_2);

        cbMEnableMuxingForcedSubtitleTracks = new QCheckBox(gbMEnableMuxingGeneral);
        cbMEnableMuxingForcedSubtitleTracks->setObjectName("cbMEnableMuxingForcedSubtitleTracks");

        verticalLayout_9->addWidget(cbMEnableMuxingForcedSubtitleTracks);


        verticalLayout_13->addWidget(gbMEnableMuxingGeneral);

        verticalLayout_13->setStretch(1, 1);
        pages->addWidget(pMergeEnableTracks);
        pMergePlaylists = new QWidget();
        pMergePlaylists->setObjectName("pMergePlaylists");
        verticalLayout_40 = new QVBoxLayout(pMergePlaylists);
        verticalLayout_40->setObjectName("verticalLayout_40");
        verticalLayout_40->setContentsMargins(0, 0, 0, 0);
        groupBox_2 = new QGroupBox(pMergePlaylists);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_54 = new QVBoxLayout(groupBox_2);
        verticalLayout_54->setObjectName("verticalLayout_54");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        cbMScanPlaylistsPolicy = new QComboBox(groupBox_2);
        cbMScanPlaylistsPolicy->addItem(QString());
        cbMScanPlaylistsPolicy->addItem(QString());
        cbMScanPlaylistsPolicy->addItem(QString());
        cbMScanPlaylistsPolicy->setObjectName("cbMScanPlaylistsPolicy");
        sizePolicy1.setHeightForWidth(cbMScanPlaylistsPolicy->sizePolicy().hasHeightForWidth());
        cbMScanPlaylistsPolicy->setSizePolicy(sizePolicy1);
        cbMScanPlaylistsPolicy->setMinimumSize(QSize(100, 0));

        gridLayout->addWidget(cbMScanPlaylistsPolicy, 0, 1, 1, 1);

        label_2 = new QLabel(groupBox_2);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        sbMMinPlaylistDuration = new mtx::gui::Util::BasicSpinBox(groupBox_2);
        sbMMinPlaylistDuration->setObjectName("sbMMinPlaylistDuration");
        sizePolicy1.setHeightForWidth(sbMMinPlaylistDuration->sizePolicy().hasHeightForWidth());
        sbMMinPlaylistDuration->setSizePolicy(sizePolicy1);
        sbMMinPlaylistDuration->setSuffix(QString::fromUtf8(" seconds"));
        sbMMinPlaylistDuration->setMaximum(99999);
        sbMMinPlaylistDuration->setSingleStep(10);

        gridLayout->addWidget(sbMMinPlaylistDuration, 1, 1, 1, 1);


        verticalLayout_54->addLayout(gridLayout);

        cbMIgnorePlaylistsForMenus = new QCheckBox(groupBox_2);
        cbMIgnorePlaylistsForMenus->setObjectName("cbMIgnorePlaylistsForMenus");

        verticalLayout_54->addWidget(cbMIgnorePlaylistsForMenus);


        verticalLayout_40->addWidget(groupBox_2);

        groupBox_21 = new QGroupBox(pMergePlaylists);
        groupBox_21->setObjectName("groupBox_21");
        verticalLayout_16 = new QVBoxLayout(groupBox_21);
        verticalLayout_16->setObjectName("verticalLayout_16");
        cbMAddBlurayCovers = new QCheckBox(groupBox_21);
        cbMAddBlurayCovers->setObjectName("cbMAddBlurayCovers");

        verticalLayout_16->addWidget(cbMAddBlurayCovers);


        verticalLayout_40->addWidget(groupBox_21);

        verticalSpacer_6 = new QSpacerItem(20, 324, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_40->addItem(verticalSpacer_6);

        pages->addWidget(pMergePlaylists);
        pInfoGeneral = new QWidget();
        pInfoGeneral->setObjectName("pInfoGeneral");
        verticalLayout_33 = new QVBoxLayout(pInfoGeneral);
        verticalLayout_33->setObjectName("verticalLayout_33");
        verticalLayout_33->setContentsMargins(0, 0, 0, 0);
        groupBox_17 = new QGroupBox(pInfoGeneral);
        groupBox_17->setObjectName("groupBox_17");
        verticalLayout_32 = new QVBoxLayout(groupBox_17);
        verticalLayout_32->setObjectName("verticalLayout_32");
        wIDefaultJobSettings = new mtx::gui::Info::JobSettingsWidget(groupBox_17);
        wIDefaultJobSettings->setObjectName("wIDefaultJobSettings");
        wIDefaultJobSettings->setFocusPolicy(Qt::StrongFocus);

        verticalLayout_32->addWidget(wIDefaultJobSettings);


        verticalLayout_33->addWidget(groupBox_17);

        verticalSpacer_11 = new QSpacerItem(20, 425, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_33->addItem(verticalSpacer_11);

        pages->addWidget(pInfoGeneral);
        pHeaderEditorGeneral = new QWidget();
        pHeaderEditorGeneral->setObjectName("pHeaderEditorGeneral");
        verticalLayout_29 = new QVBoxLayout(pHeaderEditorGeneral);
        verticalLayout_29->setObjectName("verticalLayout_29");
        verticalLayout_29->setContentsMargins(0, 0, 0, 0);
        groupBox_15 = new QGroupBox(pHeaderEditorGeneral);
        groupBox_15->setObjectName("groupBox_15");
        verticalLayout_41 = new QVBoxLayout(groupBox_15);
        verticalLayout_41->setObjectName("verticalLayout_41");
        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        label_14 = new QLabel(groupBox_15);
        label_14->setObjectName("label_14");

        horizontalLayout_11->addWidget(label_14);

        cbHEDroppedFilesPolicy = new QComboBox(groupBox_15);
        cbHEDroppedFilesPolicy->setObjectName("cbHEDroppedFilesPolicy");
        sizePolicy1.setHeightForWidth(cbHEDroppedFilesPolicy->sizePolicy().hasHeightForWidth());
        cbHEDroppedFilesPolicy->setSizePolicy(sizePolicy1);

        horizontalLayout_11->addWidget(cbHEDroppedFilesPolicy);


        verticalLayout_41->addLayout(horizontalLayout_11);

        cbHEDateTimeInUTC = new QCheckBox(groupBox_15);
        cbHEDateTimeInUTC->setObjectName("cbHEDateTimeInUTC");

        verticalLayout_41->addWidget(cbHEDateTimeInUTC);


        verticalLayout_29->addWidget(groupBox_15);

        verticalSpacer_10 = new QSpacerItem(20, 341, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_29->addItem(verticalSpacer_10);

        pages->addWidget(pHeaderEditorGeneral);
        pChapterEditorGeneral = new QWidget();
        pChapterEditorGeneral->setObjectName("pChapterEditorGeneral");
        verticalLayout_15 = new QVBoxLayout(pChapterEditorGeneral);
        verticalLayout_15->setObjectName("verticalLayout_15");
        verticalLayout_15->setContentsMargins(0, 0, 0, 0);
        groupBox_8 = new QGroupBox(pChapterEditorGeneral);
        groupBox_8->setObjectName("groupBox_8");
        QSizePolicy sizePolicy8(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy8.setHorizontalStretch(0);
        sizePolicy8.setVerticalStretch(0);
        sizePolicy8.setHeightForWidth(groupBox_8->sizePolicy().hasHeightForWidth());
        groupBox_8->setSizePolicy(sizePolicy8);
        verticalLayout_11 = new QVBoxLayout(groupBox_8);
        verticalLayout_11->setObjectName("verticalLayout_11");
        cbCEDropLastFromBlurayPlaylist = new QCheckBox(groupBox_8);
        cbCEDropLastFromBlurayPlaylist->setObjectName("cbCEDropLastFromBlurayPlaylist");

        verticalLayout_11->addWidget(cbCEDropLastFromBlurayPlaylist);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        label_17 = new QLabel(groupBox_8);
        label_17->setObjectName("label_17");

        horizontalLayout_12->addWidget(label_17);

        cbCETextFileCharacterSet = new mtx::gui::Util::CharacterSetComboBox(groupBox_8);
        cbCETextFileCharacterSet->setObjectName("cbCETextFileCharacterSet");
        sizePolicy2.setHeightForWidth(cbCETextFileCharacterSet->sizePolicy().hasHeightForWidth());
        cbCETextFileCharacterSet->setSizePolicy(sizePolicy2);

        horizontalLayout_12->addWidget(cbCETextFileCharacterSet);


        verticalLayout_11->addLayout(horizontalLayout_12);


        verticalLayout_15->addWidget(groupBox_8);

        groupBox_13 = new QGroupBox(pChapterEditorGeneral);
        groupBox_13->setObjectName("groupBox_13");
        gridLayout_3 = new QGridLayout(groupBox_13);
        gridLayout_3->setObjectName("gridLayout_3");
        leCENameTemplate = new QLineEdit(groupBox_13);
        leCENameTemplate->setObjectName("leCENameTemplate");
        leCENameTemplate->setClearButtonEnabled(true);

        gridLayout_3->addWidget(leCENameTemplate, 0, 1, 1, 1);

        label_7 = new QLabel(groupBox_13);
        label_7->setObjectName("label_7");

        gridLayout_3->addWidget(label_7, 0, 0, 1, 1);

        ldwCEDefaultLanguage = new mtx::gui::Util::LanguageDisplayWidget(groupBox_13);
        ldwCEDefaultLanguage->setObjectName("ldwCEDefaultLanguage");
        sizePolicy2.setHeightForWidth(ldwCEDefaultLanguage->sizePolicy().hasHeightForWidth());
        ldwCEDefaultLanguage->setSizePolicy(sizePolicy2);

        gridLayout_3->addWidget(ldwCEDefaultLanguage, 1, 1, 1, 1);

        label_10 = new QLabel(groupBox_13);
        label_10->setObjectName("label_10");

        gridLayout_3->addWidget(label_10, 1, 0, 1, 1);


        verticalLayout_15->addWidget(groupBox_13);

        verticalSpacer_4 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_15->addItem(verticalSpacer_4);

        pages->addWidget(pChapterEditorGeneral);
        pJobsGeneral = new QWidget();
        pJobsGeneral->setObjectName("pJobsGeneral");
        verticalLayout_14 = new QVBoxLayout(pJobsGeneral);
        verticalLayout_14->setObjectName("verticalLayout_14");
        verticalLayout_14->setContentsMargins(0, 0, 0, 0);
        groupBox_4 = new QGroupBox(pJobsGeneral);
        groupBox_4->setObjectName("groupBox_4");
        verticalLayout_2 = new QVBoxLayout(groupBox_4);
        verticalLayout_2->setObjectName("verticalLayout_2");
        cbGuiSwitchToJobOutputAfterStarting = new QCheckBox(groupBox_4);
        cbGuiSwitchToJobOutputAfterStarting->setObjectName("cbGuiSwitchToJobOutputAfterStarting");

        verticalLayout_2->addWidget(cbGuiSwitchToJobOutputAfterStarting);

        cbGuiUseDefaultJobDescription = new QCheckBox(groupBox_4);
        cbGuiUseDefaultJobDescription->setObjectName("cbGuiUseDefaultJobDescription");

        verticalLayout_2->addWidget(cbGuiUseDefaultJobDescription);

        cbGuiShowOutputOfAllJobs = new QCheckBox(groupBox_4);
        cbGuiShowOutputOfAllJobs->setObjectName("cbGuiShowOutputOfAllJobs");

        verticalLayout_2->addWidget(cbGuiShowOutputOfAllJobs);

        cbGuiResetJobWarningErrorCountersOnExit = new QCheckBox(groupBox_4);
        cbGuiResetJobWarningErrorCountersOnExit->setObjectName("cbGuiResetJobWarningErrorCountersOnExit");

        verticalLayout_2->addWidget(cbGuiResetJobWarningErrorCountersOnExit);

        cbGuiRemoveOutputFileOnJobFailure = new QCheckBox(groupBox_4);
        cbGuiRemoveOutputFileOnJobFailure->setObjectName("cbGuiRemoveOutputFileOnJobFailure");

        verticalLayout_2->addWidget(cbGuiRemoveOutputFileOnJobFailure);

        gridLayout_7 = new QGridLayout();
        gridLayout_7->setObjectName("gridLayout_7");
        cbGuiRemoveOldJobs = new QCheckBox(groupBox_4);
        cbGuiRemoveOldJobs->setObjectName("cbGuiRemoveOldJobs");

        gridLayout_7->addWidget(cbGuiRemoveOldJobs, 2, 0, 1, 1);

        cbGuiRemoveJobsOnExit = new QCheckBox(groupBox_4);
        cbGuiRemoveJobsOnExit->setObjectName("cbGuiRemoveJobsOnExit");

        gridLayout_7->addWidget(cbGuiRemoveJobsOnExit, 1, 0, 1, 1);

        cbGuiRemoveJobs = new QCheckBox(groupBox_4);
        cbGuiRemoveJobs->setObjectName("cbGuiRemoveJobs");

        gridLayout_7->addWidget(cbGuiRemoveJobs, 0, 0, 1, 1);

        cbGuiJobRemovalPolicy = new QComboBox(groupBox_4);
        cbGuiJobRemovalPolicy->addItem(QString());
        cbGuiJobRemovalPolicy->addItem(QString());
        cbGuiJobRemovalPolicy->addItem(QString());
        cbGuiJobRemovalPolicy->setObjectName("cbGuiJobRemovalPolicy");

        gridLayout_7->addWidget(cbGuiJobRemovalPolicy, 0, 1, 1, 1);

        sbGuiRemoveOldJobsDays = new mtx::gui::Util::BasicSpinBox(groupBox_4);
        sbGuiRemoveOldJobsDays->setObjectName("sbGuiRemoveOldJobsDays");
        sbGuiRemoveOldJobsDays->setSuffix(QString::fromUtf8(" days"));
        sbGuiRemoveOldJobsDays->setMinimum(1);
        sbGuiRemoveOldJobsDays->setMaximum(365);

        gridLayout_7->addWidget(sbGuiRemoveOldJobsDays, 2, 1, 1, 1);

        cbGuiJobRemovalOnExitPolicy = new QComboBox(groupBox_4);
        cbGuiJobRemovalOnExitPolicy->addItem(QString());
        cbGuiJobRemovalOnExitPolicy->addItem(QString());
        cbGuiJobRemovalOnExitPolicy->addItem(QString());
        cbGuiJobRemovalOnExitPolicy->setObjectName("cbGuiJobRemovalOnExitPolicy");

        gridLayout_7->addWidget(cbGuiJobRemovalOnExitPolicy, 1, 1, 1, 1);

        label_22 = new QLabel(groupBox_4);
        label_22->setObjectName("label_22");

        gridLayout_7->addWidget(label_22, 3, 0, 1, 1);

        sbGuiMaximumConcurrentJobs = new mtx::gui::Util::BasicSpinBox(groupBox_4);
        sbGuiMaximumConcurrentJobs->setObjectName("sbGuiMaximumConcurrentJobs");
        sbGuiMaximumConcurrentJobs->setMinimum(1);

        gridLayout_7->addWidget(sbGuiMaximumConcurrentJobs, 3, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout_7);


        verticalLayout_14->addWidget(groupBox_4);

        verticalSpacer_5 = new QSpacerItem(20, 205, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_14->addItem(verticalSpacer_5);

        pages->addWidget(pJobsGeneral);
        pJobsExecutePrograms = new QWidget();
        pJobsExecutePrograms->setObjectName("pJobsExecutePrograms");
        verticalLayout_28 = new QVBoxLayout(pJobsExecutePrograms);
        verticalLayout_28->setObjectName("verticalLayout_28");
        verticalLayout_28->setContentsMargins(0, 0, 0, 0);
        groupBox_14 = new QGroupBox(pJobsExecutePrograms);
        groupBox_14->setObjectName("groupBox_14");
        verticalLayout_27 = new QVBoxLayout(groupBox_14);
        verticalLayout_27->setObjectName("verticalLayout_27");
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_6);

        pbJobsAddProgram = new QPushButton(groupBox_14);
        pbJobsAddProgram->setObjectName("pbJobsAddProgram");
        pbJobsAddProgram->setIcon(icon);

        horizontalLayout_4->addWidget(pbJobsAddProgram);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_5);


        verticalLayout_27->addLayout(horizontalLayout_4);

        swJobsPrograms = new QStackedWidget(groupBox_14);
        swJobsPrograms->setObjectName("swJobsPrograms");
        pJobsNoPrograms = new QWidget();
        pJobsNoPrograms->setObjectName("pJobsNoPrograms");
        verticalLayout_25 = new QVBoxLayout(pJobsNoPrograms);
        verticalLayout_25->setObjectName("verticalLayout_25");
        verticalLayout_25->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        label_8 = new QLabel(pJobsNoPrograms);
        label_8->setObjectName("label_8");

        horizontalLayout_6->addWidget(label_8);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_7);


        verticalLayout_25->addLayout(horizontalLayout_6);

        verticalSpacer_9 = new QSpacerItem(20, 329, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_25->addItem(verticalSpacer_9);

        swJobsPrograms->addWidget(pJobsNoPrograms);
        pJobsExistingPrograms = new QWidget();
        pJobsExistingPrograms->setObjectName("pJobsExistingPrograms");
        verticalLayout_26 = new QVBoxLayout(pJobsExistingPrograms);
        verticalLayout_26->setObjectName("verticalLayout_26");
        verticalLayout_26->setContentsMargins(0, 0, 0, 0);
        twJobsPrograms = new mtx::gui::Util::BasicTabWidget(pJobsExistingPrograms);
        twJobsPrograms->setObjectName("twJobsPrograms");
        twJobsPrograms->setTabsClosable(true);
        twJobsPrograms->setMovable(true);

        verticalLayout_26->addWidget(twJobsPrograms);

        swJobsPrograms->addWidget(pJobsExistingPrograms);

        verticalLayout_27->addWidget(swJobsPrograms);


        verticalLayout_28->addWidget(groupBox_14);

        pages->addWidget(pJobsExecutePrograms);
        pagesSplitter->addWidget(pages);

        verticalLayout_24->addWidget(pagesSplitter);

        buttons = new QDialogButtonBox(mtx__gui__PreferencesDialog);
        buttons->setObjectName("buttons");
        buttons->setOrientation(Qt::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_24->addWidget(buttons);

#if QT_CONFIG(shortcut)
        label_24->setBuddy(sbGuiNumRecentlyUsedStrings);
        label_3->setBuddy(cbGuiInterfaceLanguage);
        label_12->setBuddy(fcbGuiFontFamily);
        cbGuiPaletteLabel->setBuddy(cbGuiPalette);
        label_9->setBuddy(cbGuiTabPositions);
        label_26->setBuddy(cbGuiBCP47LanguageEditingMode);
        label_11->setBuddy(cbGuiBCP47NormalizationMode);
        label_19->setBuddy(cbMWarnMissingAudioTrack);
        label_16->setBuddy(cbMProbeRangePercentage);
        label_6->setBuddy(cbMClearMergeSettings);
        label_20->setBuddy(leMMediaInfoExe);
        label_5->setBuddy(cbMProcessPriority);
        label_21->setBuddy(cbMDefaultCommandLineEscapeMode);
        label_23->setBuddy(cbMDragAndDropFilesPolicy);
        label_13->setBuddy(cbMAddingAppendingFilesPolicy);
        label_25->setBuddy(cbMDragAndDropDirectoriesPolicy);
        label_15->setBuddy(leMDefaultAdditionalCommandLineOptions);
        label_4->setBuddy(cbMDefaultSubtitleCharset);
        lDefaultAudioTrackLanguage->setBuddy(ldwMDefaultAudioTrackLanguage);
        lDefaultVideoTrackLanguage->setBuddy(ldwMDefaultVideoTrackLanguage);
        lDefaultSubtitleTrackLanguage->setBuddy(ldwMDefaultSubtitleTrackLanguage);
        lWhenToSetDefaultLanguage->setBuddy(cbMWhenToSetDefaultLanguage);
        lDeriveAudioTrackLanguageFromFileName->setBuddy(cbMDeriveAudioTrackLanguageFromFileName);
        lDeriveVideoTrackLanguageFromFileName->setBuddy(cbMDeriveVideoTrackLanguageFromFileName);
        lDeriveSubtitleTrackLanguageFromFileName->setBuddy(cbMDeriveSubtitleTrackLanguageFromFileName);
        label_18->setBuddy(leMDeriveTrackLanguageBoundaryChars);
        label->setBuddy(cbMScanPlaylistsPolicy);
        label_2->setBuddy(sbMMinPlaylistDuration);
        label_14->setBuddy(cbHEDroppedFilesPolicy);
        label_17->setBuddy(cbCETextFileCharacterSet);
        label_7->setBuddy(leCENameTemplate);
        label_22->setBuddy(sbGuiMaximumConcurrentJobs);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(pageSelector, cbGuiInterfaceLanguage);
        QWidget::setTabOrder(cbGuiInterfaceLanguage, fcbGuiFontFamily);
        QWidget::setTabOrder(fcbGuiFontFamily, cbGuiPalette);
        QWidget::setTabOrder(cbGuiPalette, sbGuiFontPointSize);
        QWidget::setTabOrder(sbGuiFontPointSize, sbGuiNumRecentlyUsedStrings);
        QWidget::setTabOrder(sbGuiNumRecentlyUsedStrings, cbGuiStayOnTop);
        QWidget::setTabOrder(cbGuiStayOnTop, cbGuiDisableHighDPIScaling);
        QWidget::setTabOrder(cbGuiDisableHighDPIScaling, cbGuiDisableToolTips);
        QWidget::setTabOrder(cbGuiDisableToolTips, cbGuiCheckForUpdates);
        QWidget::setTabOrder(cbGuiCheckForUpdates, cbGuiUseLegacyFontMIMETypes);
        QWidget::setTabOrder(cbGuiUseLegacyFontMIMETypes, cbGuiShowDebuggingMenu);
        QWidget::setTabOrder(cbGuiShowDebuggingMenu, cbGuiTabPositions);
        QWidget::setTabOrder(cbGuiTabPositions, cbGuiBCP47LanguageEditingMode);
        QWidget::setTabOrder(cbGuiBCP47LanguageEditingMode, cbGuiElideTabHeaderLabels);
        QWidget::setTabOrder(cbGuiElideTabHeaderLabels, cbGuiShowToolSelector);
        QWidget::setTabOrder(cbGuiShowToolSelector, cbGuiShowMoveUpDownButtons);
        QWidget::setTabOrder(cbGuiShowMoveUpDownButtons, cbGuiWarnBeforeClosingModifiedTabs);
        QWidget::setTabOrder(cbGuiWarnBeforeClosingModifiedTabs, cbGuiWarnBeforeAbortingJobs);
        QWidget::setTabOrder(cbGuiWarnBeforeAbortingJobs, cbGuiWarnBeforeOverwriting);
        QWidget::setTabOrder(cbGuiWarnBeforeOverwriting, tbOftenUsedXYZ);
        QWidget::setTabOrder(tbOftenUsedXYZ, tbOftenUsedLanguages);
        QWidget::setTabOrder(tbOftenUsedLanguages, cbGuiBCP47LanguageEditingMode);
        QWidget::setTabOrder(cbGuiBCP47LanguageEditingMode, cbGuiBCP47NormalizationMode);
        QWidget::setTabOrder(cbGuiBCP47NormalizationMode, cbUseISO639_3Languages);
        QWidget::setTabOrder(cbUseISO639_3Languages, cbOftenUsedLanguagesOnly);
        QWidget::setTabOrder(cbOftenUsedLanguagesOnly, tbOftenUsedRegions);
        QWidget::setTabOrder(tbOftenUsedRegions, cbOftenUsedRegionsOnly);
        QWidget::setTabOrder(cbOftenUsedRegionsOnly, tbOftenUsedCharacterSets);
        QWidget::setTabOrder(tbOftenUsedCharacterSets, cbOftenUsedCharacterSetsOnly);
        QWidget::setTabOrder(cbOftenUsedCharacterSetsOnly, twGuiLanguageShortcuts);
        QWidget::setTabOrder(twGuiLanguageShortcuts, pbGuiAddLanguageShortcut);
        QWidget::setTabOrder(pbGuiAddLanguageShortcut, pbGuiEditLanguageShortcut);
        QWidget::setTabOrder(pbGuiEditLanguageShortcut, pbGuiRemoveLanguageShortcuts);
        QWidget::setTabOrder(pbGuiRemoveLanguageShortcuts, cbMClearMergeSettings);
        QWidget::setTabOrder(cbMClearMergeSettings, cbMWarnMissingAudioTrack);
        QWidget::setTabOrder(cbMWarnMissingAudioTrack, cbMProcessPriority);
        QWidget::setTabOrder(cbMProcessPriority, cbMProbeRangePercentage);
        QWidget::setTabOrder(cbMProbeRangePercentage, cbMDefaultCommandLineEscapeMode);
        QWidget::setTabOrder(cbMDefaultCommandLineEscapeMode, leMMediaInfoExe);
        QWidget::setTabOrder(leMMediaInfoExe, pbMBrowseMediaInfoExe);
        QWidget::setTabOrder(pbMBrowseMediaInfoExe, cbMEnsureAtLeastOneTrackEnabled);
        QWidget::setTabOrder(cbMEnsureAtLeastOneTrackEnabled, cbMAddingAppendingFilesPolicy);
        QWidget::setTabOrder(cbMAddingAppendingFilesPolicy, cbMDragAndDropFilesPolicy);
        QWidget::setTabOrder(cbMDragAndDropFilesPolicy, cbMDragAndDropDirectoriesPolicy);
        QWidget::setTabOrder(cbMDragAndDropDirectoriesPolicy, cbMAlwaysCreateSettingsForVideoFiles);
        QWidget::setTabOrder(cbMAlwaysCreateSettingsForVideoFiles, cbMShowDNDZones);
        QWidget::setTabOrder(cbMShowDNDZones, cbMSortFilesTracksByTypeWhenAdding);
        QWidget::setTabOrder(cbMSortFilesTracksByTypeWhenAdding, cbMReconstructSequencesWhenAdding);
        QWidget::setTabOrder(cbMReconstructSequencesWhenAdding, cbMAttachmentAlwaysSkipForExistingName);
        QWidget::setTabOrder(cbMAttachmentAlwaysSkipForExistingName, cbMAlwaysShowOutputFileControls);
        QWidget::setTabOrder(cbMAlwaysShowOutputFileControls, rbMTrackPropertiesLayoutHorizontalScrollArea);
        QWidget::setTabOrder(rbMTrackPropertiesLayoutHorizontalScrollArea, rbMTrackPropertiesLayoutHorizontalTwoColumns);
        QWidget::setTabOrder(rbMTrackPropertiesLayoutHorizontalTwoColumns, rbMTrackPropertiesLayoutVerticalTabWidget);
        QWidget::setTabOrder(rbMTrackPropertiesLayoutVerticalTabWidget, cbMUseFileAndTrackColors);
        QWidget::setTabOrder(cbMUseFileAndTrackColors, lwMFileColors);
        QWidget::setTabOrder(lwMFileColors, pbMAddFileColor);
        QWidget::setTabOrder(pbMAddFileColor, pbMRemoveFileColors);
        QWidget::setTabOrder(pbMRemoveFileColors, pbMEditFileColor);
        QWidget::setTabOrder(pbMEditFileColor, pbMRevertFileColorsToDefault);
        QWidget::setTabOrder(pbMRevertFileColorsToDefault, leMDefaultAdditionalCommandLineOptions);
        QWidget::setTabOrder(leMDefaultAdditionalCommandLineOptions, pbMEditDefaultAdditionalCommandLineOptions);
        QWidget::setTabOrder(pbMEditDefaultAdditionalCommandLineOptions, cbMAutoSetFileTitle);
        QWidget::setTabOrder(cbMAutoSetFileTitle, cbMAutoClearFileTitle);
        QWidget::setTabOrder(cbMAutoClearFileTitle, cbMSetAudioDelayFromFileName);
        QWidget::setTabOrder(cbMSetAudioDelayFromFileName, cbMDisableDefaultTrackForSubtitles);
        QWidget::setTabOrder(cbMDisableDefaultTrackForSubtitles, cbMDisableCompressionForAllTrackTypes);
        QWidget::setTabOrder(cbMDisableCompressionForAllTrackTypes, cbMEnableDialogNormGainRemoval);
        QWidget::setTabOrder(cbMEnableDialogNormGainRemoval, cbMDeriveForcedDisplayFlagSubtitles);
        QWidget::setTabOrder(cbMDeriveForcedDisplayFlagSubtitles, leMDeriveForcedDisplayFlagSubtitlesRE);
        QWidget::setTabOrder(leMDeriveForcedDisplayFlagSubtitlesRE, pbMDeriveForcedDisplayFlagSubtitlesRERevert);
        QWidget::setTabOrder(pbMDeriveForcedDisplayFlagSubtitlesRERevert, cbMDeriveHearingImpairedFlag);
        QWidget::setTabOrder(cbMDeriveHearingImpairedFlag, leMDeriveHearingImpairedFlagRE);
        QWidget::setTabOrder(leMDeriveHearingImpairedFlagRE, pbMDeriveHearingImpairedFlagRERevert);
        QWidget::setTabOrder(pbMDeriveHearingImpairedFlagRERevert, cbMDeriveCommentaryFlag);
        QWidget::setTabOrder(cbMDeriveCommentaryFlag, leMDeriveCommentaryFlagRE);
        QWidget::setTabOrder(leMDeriveCommentaryFlagRE, pbMDeriveCommentaryFlagRERevert);
        QWidget::setTabOrder(pbMDeriveCommentaryFlagRERevert, cbMSetOriginalLanguageFlagLanguage);
        QWidget::setTabOrder(cbMSetOriginalLanguageFlagLanguage, ldwMSetOriginalLanguageFlagLanguage);
        QWidget::setTabOrder(ldwMSetOriginalLanguageFlagLanguage, cbMDefaultSubtitleCharset);
        QWidget::setTabOrder(cbMDefaultSubtitleCharset, cbMDeriveFlagsFromTrackNames);
        QWidget::setTabOrder(cbMDeriveFlagsFromTrackNames, cbMWhenToSetDefaultLanguage);
        QWidget::setTabOrder(cbMWhenToSetDefaultLanguage, cbMDeriveAudioTrackLanguageFromFileName);
        QWidget::setTabOrder(cbMDeriveAudioTrackLanguageFromFileName, cbMDeriveVideoTrackLanguageFromFileName);
        QWidget::setTabOrder(cbMDeriveVideoTrackLanguageFromFileName, cbMDeriveSubtitleTrackLanguageFromFileName);
        QWidget::setTabOrder(cbMDeriveSubtitleTrackLanguageFromFileName, leMDeriveTrackLanguageBoundaryChars);
        QWidget::setTabOrder(leMDeriveTrackLanguageBoundaryChars, pbMDeriveTrackLanguageRevertBoundaryChars);
        QWidget::setTabOrder(pbMDeriveTrackLanguageRevertBoundaryChars, tbMDeriveTrackLanguageRecognizedLanguages);
        QWidget::setTabOrder(tbMDeriveTrackLanguageRecognizedLanguages, cbMAutoSetDestinationFileName);
        QWidget::setTabOrder(cbMAutoSetDestinationFileName, cbMAutoSetDestinationOnlyForVideoFiles);
        QWidget::setTabOrder(cbMAutoSetDestinationOnlyForVideoFiles, cbMAutoSetDestinationFromTitle);
        QWidget::setTabOrder(cbMAutoSetDestinationFromTitle, cbMAutoSetDestinationFromDirectory);
        QWidget::setTabOrder(cbMAutoSetDestinationFromDirectory, rbMAutoSetDestinationSameDirectory);
        QWidget::setTabOrder(rbMAutoSetDestinationSameDirectory, rbMAutoSetDestinationPreviousDirectory);
        QWidget::setTabOrder(rbMAutoSetDestinationPreviousDirectory, rbMAutoSetDestinationRelativeDirectory);
        QWidget::setTabOrder(rbMAutoSetDestinationRelativeDirectory, cbMAutoSetDestinationRelativeDirectory);
        QWidget::setTabOrder(cbMAutoSetDestinationRelativeDirectory, rbMAutoSetDestinationFixedDirectory);
        QWidget::setTabOrder(rbMAutoSetDestinationFixedDirectory, cbMAutoSetDestinationFixedDirectory);
        QWidget::setTabOrder(cbMAutoSetDestinationFixedDirectory, pbMAutoSetDestinationBrowseFixedDirectory);
        QWidget::setTabOrder(pbMAutoSetDestinationBrowseFixedDirectory, cbMUniqueOutputFileNames);
        QWidget::setTabOrder(cbMUniqueOutputFileNames, cbMAutoClearOutputFileName);
        QWidget::setTabOrder(cbMAutoClearOutputFileName, tbMEnableMuxingTracksByType);
        QWidget::setTabOrder(tbMEnableMuxingTracksByType, cbMEnableMuxingTracksByLanguage);
        QWidget::setTabOrder(cbMEnableMuxingTracksByLanguage, tbMEnableMuxingTracksByLanguage);
        QWidget::setTabOrder(tbMEnableMuxingTracksByLanguage, cbMEnableMuxingAllVideoTracks);
        QWidget::setTabOrder(cbMEnableMuxingAllVideoTracks, cbMEnableMuxingAllAudioTracks);
        QWidget::setTabOrder(cbMEnableMuxingAllAudioTracks, cbMEnableMuxingAllSubtitleTracks);
        QWidget::setTabOrder(cbMEnableMuxingAllSubtitleTracks, cbMEnableMuxingForcedSubtitleTracks);
        QWidget::setTabOrder(cbMEnableMuxingForcedSubtitleTracks, cbMScanPlaylistsPolicy);
        QWidget::setTabOrder(cbMScanPlaylistsPolicy, sbMMinPlaylistDuration);
        QWidget::setTabOrder(sbMMinPlaylistDuration, cbMIgnorePlaylistsForMenus);
        QWidget::setTabOrder(cbMIgnorePlaylistsForMenus, cbMAddBlurayCovers);
        QWidget::setTabOrder(cbMAddBlurayCovers, wIDefaultJobSettings);
        QWidget::setTabOrder(wIDefaultJobSettings, cbHEDroppedFilesPolicy);
        QWidget::setTabOrder(cbHEDroppedFilesPolicy, cbHEDateTimeInUTC);
        QWidget::setTabOrder(cbHEDateTimeInUTC, cbCEDropLastFromBlurayPlaylist);
        QWidget::setTabOrder(cbCEDropLastFromBlurayPlaylist, cbCETextFileCharacterSet);
        QWidget::setTabOrder(cbCETextFileCharacterSet, leCENameTemplate);
        QWidget::setTabOrder(leCENameTemplate, cbGuiSwitchToJobOutputAfterStarting);
        QWidget::setTabOrder(cbGuiSwitchToJobOutputAfterStarting, cbGuiUseDefaultJobDescription);
        QWidget::setTabOrder(cbGuiUseDefaultJobDescription, cbGuiShowOutputOfAllJobs);
        QWidget::setTabOrder(cbGuiShowOutputOfAllJobs, cbGuiResetJobWarningErrorCountersOnExit);
        QWidget::setTabOrder(cbGuiResetJobWarningErrorCountersOnExit, cbGuiRemoveOutputFileOnJobFailure);
        QWidget::setTabOrder(cbGuiRemoveOutputFileOnJobFailure, cbGuiRemoveJobs);
        QWidget::setTabOrder(cbGuiRemoveJobs, cbGuiJobRemovalPolicy);
        QWidget::setTabOrder(cbGuiJobRemovalPolicy, cbGuiRemoveJobsOnExit);
        QWidget::setTabOrder(cbGuiRemoveJobsOnExit, cbGuiJobRemovalOnExitPolicy);
        QWidget::setTabOrder(cbGuiJobRemovalOnExitPolicy, cbGuiRemoveOldJobs);
        QWidget::setTabOrder(cbGuiRemoveOldJobs, sbGuiRemoveOldJobsDays);
        QWidget::setTabOrder(sbGuiRemoveOldJobsDays, sbGuiMaximumConcurrentJobs);
        QWidget::setTabOrder(sbGuiMaximumConcurrentJobs, pbJobsAddProgram);
        QWidget::setTabOrder(pbJobsAddProgram, twJobsPrograms);

        retranslateUi(mtx__gui__PreferencesDialog);

        pages->setCurrentIndex(0);
        tbOftenUsedXYZ->setCurrentIndex(0);
        swJobsPrograms->setCurrentIndex(0);
        twJobsPrograms->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(mtx__gui__PreferencesDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__PreferencesDialog)
    {
        mtx__gui__PreferencesDialog->setWindowTitle(QTR("MKVToolNix GUI preferences", nullptr));
        groupBox->setTitle(QTR("General options", nullptr));
        label_24->setText(QTR("Number of &recently used entries to remember:", nullptr));
        label_3->setText(QTR("Interface &language:", nullptr));
        label_12->setText(QTR("&Font && size:", nullptr));
        cbGuiPalette->setItemText(0, QTR("Use system settings", nullptr));
        cbGuiPalette->setItemText(1, QTR("Light", nullptr));
        cbGuiPalette->setItemText(2, QTR("Dark", nullptr));

        cbGuiPaletteLabel->setText(QTR("Color palette:", nullptr));
        cbGuiStayOnTop->setText(QTR("Stay on top of other &windows", nullptr));
        cbGuiDisableHighDPIScaling->setText(QTR("Disable scaling for &high DPI displays", nullptr));
        cbGuiDisableToolTips->setText(QTR("Disable &tooltips", nullptr));
        cbGuiCheckForUpdates->setText(QTR("Check online for available &updates", nullptr));
        cbGuiUseLegacyFontMIMETypes->setText(QTR("Use legac&y MIME types for font attachments", nullptr));
        cbGuiShowDebuggingMenu->setText(QTR("Show debu&gging menu", nullptr));
        groupBox_16->setTitle(QTR("Layout", nullptr));
        label_9->setText(QTR("Tab &position in tab widgets:", nullptr));
        cbGuiElideTabHeaderLabels->setText(QTR("&Elide text in tab headers of tab widgets", nullptr));
        cbGuiShowToolSelector->setText(QTR("Show the tool &selector", nullptr));
        cbGuiShowMoveUpDownButtons->setText(QTR("Show &buttons for moving list view entries up and down", nullptr));
        groupBox_6->setTitle(QTR("Warnings", nullptr));
        cbGuiWarnBeforeClosingModifiedTabs->setText(QTR("Warn before &closing modified tabs", nullptr));
        cbGuiWarnBeforeAbortingJobs->setText(QTR("Warn before &aborting running jobs", nullptr));
        cbGuiWarnBeforeOverwriting->setText(QTR("Warn before &overwriting existing items (files, jobs etc.)", nullptr));
        cbOftenUsedLanguagesOnly->setText(QTR("&Only include often used entries in selections", nullptr));
        tbOftenUsedXYZ->setTabText(tbOftenUsedXYZ->indexOf(oftenUsedLanguagesTab), QTR("&Languages", nullptr));
        cbOftenUsedRegionsOnly->setText(QTR("&Only include often used entries in selections", nullptr));
        tbOftenUsedXYZ->setTabText(tbOftenUsedXYZ->indexOf(oftenUsedRegionsTab), QTR("C&ountries && regions", nullptr));
        cbOftenUsedCharacterSetsOnly->setText(QTR("&Only include often used entries in selections", nullptr));
        tbOftenUsedXYZ->setTabText(tbOftenUsedXYZ->indexOf(oftenUsedCharacterSetsTab), QTR("&Character sets", nullptr));
        groupBox_27->setTitle(QTR("General options", nullptr));
        label_26->setText(QTR("Default IETF BCP 47 language editing &mode:", nullptr));
        label_11->setText(QTR("IETF BCP 47 &normalization mode:", nullptr));
        cbUseISO639_3Languages->setText(QTR("Enable language codes from &ISO 639-3 && 639-5", nullptr));
        groupBox_26->setTitle(QTR("Language shortcuts", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = twGuiLanguageShortcuts->headerItem();
        ___qtreewidgetitem->setText(1, QTR("Track name", nullptr));
        ___qtreewidgetitem->setText(0, QTR("Language", nullptr));
        groupBox_3->setTitle(QTR("General options", nullptr));
        pbMBrowseMediaInfoExe->setText(QString());
        label_19->setText(QTR("Warn about missing &audio tracks:", nullptr));
        label_16->setText(QTR("Probe &range percentage:", nullptr));
        label_6->setText(QTR("Clearing settings auto&matically:", nullptr));
        cbMClearMergeSettings->setItemText(0, QTR("No", nullptr));
        cbMClearMergeSettings->setItemText(1, QTR("Create new settings", nullptr));
        cbMClearMergeSettings->setItemText(2, QTR("Remove source files", nullptr));
        cbMClearMergeSettings->setItemText(3, QTR("Close current settings", nullptr));

        label_20->setText(QTR("Location of MediaInfo &GUI:", nullptr));
        label_5->setText(QTR("Process &priority:", nullptr));
        label_21->setText(QTR("Default command-&line escape mode:", nullptr));
        cbMEnsureAtLeastOneTrackEnabled->setText(QTR("&Ensure at least one track of each type has its \"track enabled\" flag set", nullptr));
        groupBox_23->setTitle(QTR("Adding files", nullptr));
        label_23->setText(QTR("When adding files via &drag && drop/copy && paste:", nullptr));
        label_13->setText(QTR("When adding m&ultiple files via \"add source files\":", nullptr));
        label_25->setText(QTR("When adding d&irectories via drag && drop/copy && paste:", nullptr));
        cbMAlwaysCreateSettingsForVideoFiles->setText(QTR("Alwa&ys create new mutliplex settings for files containing video tracks", nullptr));
        cbMShowDNDZones->setText(QTR("Show special drag && drop &zones", nullptr));
        cbMSortFilesTracksByTypeWhenAdding->setText(QTR("S&ort files && tracks by track type when adding files", nullptr));
        cbMReconstructSequencesWhenAdding->setText(QTR("Detect file name se&quences when adding multiple files", nullptr));
        groupBox_25->setTitle(QTR("Attachments", nullptr));
        cbMAttachmentAlwaysSkipForExistingName->setText(QTR("Always s&kip while attaching new files when attachment with same name exists", nullptr));
        groupBox_12->setTitle(QTR("Layout", nullptr));
        cbMAlwaysShowOutputFileControls->setText(QTR("Always show the destination file controls &below tabs", nullptr));
        cbMTrackPropertiesLayoutLabel->setText(QTR("Position for the track properties on the \"input\" tab:", nullptr));
        rbMTrackPropertiesLayoutHorizontalScrollArea->setText(QTR("In a &scrollable column on the right of the files and tracks", nullptr));
        rbMTrackPropertiesLayoutHorizontalTwoColumns->setText(QTR("In &two fixed columns on the right of the files and tracks", nullptr));
        rbMTrackPropertiesLayoutVerticalTabWidget->setText(QTR("In a tab &widget below the files and tracks", nullptr));
        groupBox_24->setTitle(QTR("File && track colors", nullptr));
        cbMUseFileAndTrackColors->setText(QTR("Use &file && track colors", nullptr));
#if QT_CONFIG(tooltip)
        pbMRevertFileColorsToDefault->setToolTip(QTR("Revert to default colors", nullptr));
#endif // QT_CONFIG(tooltip)
        gpMPredefinedVideoTrackNames->setTitle(QTR("Predefined video track names", nullptr));
        gpMPredefinedAudioTrackNames->setTitle(QTR("Predefined audio track names", nullptr));
        gpMPredefinedSubtitleTrackNames->setTitle(QTR("Predefined subtitle track names", nullptr));
        gbMPredefinedSplitSizes->setTitle(QTR("Predefined split sizes", nullptr));
        gbMPredefinedSplitDurations->setTitle(QTR("Predefined split durations", nullptr));
        groupBox_11->setTitle(QTR("Defaults for new multiplex settings", nullptr));
        label_15->setText(QTR("Default additional co&mmand line options:", nullptr));
        pbMEditDefaultAdditionalCommandLineOptions->setText(QString());
        groupBox_10->setTitle(QTR("Defaults for newly added tracks", nullptr));
        cbMAutoSetFileTitle->setText(QTR("Automatically set the file &title from source files", nullptr));
        cbMAutoClearFileTitle->setText(QTR("Automatically clea&r the file title when the last file is removed", nullptr));
        cbMSetAudioDelayFromFileName->setText(QTR("Automatically set track &delays from source file name", nullptr));
        cbMDisableDefaultTrackForSubtitles->setText(QTR("Disable \"de&fault track\" flag for subtitle tracks", nullptr));
        cbMDisableCompressionForAllTrackTypes->setText(QTR("Disable additional lossless c&ompression for all track types", nullptr));
        cbMEnableDialogNormGainRemoval->setText(QTR("Enable dialog &normalization gain removal for audio tracks", nullptr));
        cbMDeriveForcedDisplayFlagSubtitles->setText(QTR("Derive \"forced display\" fla&g for subtitles from file names:", nullptr));
        cbMDeriveCommentaryFlag->setText(QTR("Derive \"commentar&y\" flag for audio/subtitles from file names:", nullptr));
        cbMSetOriginalLanguageFlagLanguage->setText(QTR("Set \"original language\" flag for audio/subtitles for language:", nullptr));
        cbMDeriveHearingImpairedFlag->setText(QTR("Derive \"&hearing impaired\" flag for audio/subtitles from file names:", nullptr));
        label_4->setText(QTR("Default subtitle &charset to set:", nullptr));
        cbMDeriveFlagsFromTrackNames->setText(QTR("Derive flags from trac&k names in addition to file names", nullptr));
        groupBox_9->setTitle(QTR("Default track languages to set", nullptr));
        lDefaultAudioTrackLanguage->setText(QTR("&Audio tracks:", nullptr));
        lDefaultVideoTrackLanguage->setText(QTR("&Video tracks:", nullptr));
        lDefaultSubtitleTrackLanguage->setText(QTR("&Subtitle tracks:", nullptr));
        lWhenToSetDefaultLanguage->setText(QTR("&When to set the language:", nullptr));
        groupBox_18->setTitle(QTR("Deriving track languages from file names", nullptr));
        lDeriveAudioTrackLanguageFromFileName->setText(QTR("&Audio tracks:", nullptr));
        lDeriveVideoTrackLanguageFromFileName->setText(QTR("&Video tracks:", nullptr));
        lDeriveSubtitleTrackLanguageFromFileName->setText(QTR("&Subtitle tracks:", nullptr));
        label_18->setText(QTR("&Boundary characters:", nullptr));
        groupBox_19->setTitle(QTR("Recognized languages", nullptr));
        groupBox_5->setTitle(QTR("Destination file name", nullptr));
        cbMAutoSetDestinationFileName->setText(QTR("&Automatically set the destination file name", nullptr));
        cbMAutoSetDestinationOnlyForVideoFiles->setText(QTR("&Only use the first source file that contains a video track", nullptr));
        cbMAutoSetDestinationFromTitle->setText(QTR("Use the &title as the base file name if a title is set", nullptr));
        cbMAutoSetDestinationFromDirectory->setText(QTR("Use the input file's &directory name instead of the file name", nullptr));
        gbMAutoSetDestinationDirectory->setTitle(QTR("Destination directory", nullptr));
        rbMAutoSetDestinationSameDirectory->setText(QTR("Sa&me directory as the first source file", nullptr));
        rbMAutoSetDestinationPreviousDirectory->setText(QTR("Pre&viously used destination directory", nullptr));
        rbMAutoSetDestinationRelativeDirectory->setText(QTR("Directory &relative to first source file's directory:", nullptr));
        rbMAutoSetDestinationFixedDirectory->setText(QTR("Use fi&xed directory:", nullptr));
        pbMAutoSetDestinationBrowseFixedDirectory->setText(QString());
        cbMUniqueOutputFileNames->setText(QTR("Ensure the file name is &unique", nullptr));
        cbMAutoClearOutputFileName->setText(QTR("Automatically &clear the destination file name when the last file is removed", nullptr));
        groupBox_22->setTitle(QTR("Recent destination directories", nullptr));
        groupBox_20->setTitle(QTR("Enable copying of items by their type", nullptr));
        groupBox_7->setTitle(QTR("Enable copying of tracks by their language", nullptr));
        cbMEnableMuxingTracksByLanguage->setText(QTR("&Only enable copying of tracks with specific languages by default", nullptr));
        gbMEnableMuxingGeneral->setTitle(QTR("General options", nullptr));
        lMEnableMuxingAllTracksOfType->setText(QTR("Always enable copying for all tracks of the following types regardless of their language:", nullptr));
        cbMEnableMuxingAllVideoTracks->setText(QTR("&Video", nullptr));
        cbMEnableMuxingAllAudioTracks->setText(QTR("&Audio", nullptr));
        cbMEnableMuxingAllSubtitleTracks->setText(QTR("&Subtitles", nullptr));
        cbMEnableMuxingForcedSubtitleTracks->setText(QTR("Always enable copying of &forced subtitle tracks", nullptr));
        groupBox_2->setTitle(QTR("Scanning playlists", nullptr));
        label->setText(QTR("&Scan directory for other playlists:", nullptr));
        cbMScanPlaylistsPolicy->setItemText(0, QTR("Always ask the user", nullptr));
        cbMScanPlaylistsPolicy->setItemText(1, QTR("Always scan for other playlists", nullptr));
        cbMScanPlaylistsPolicy->setItemText(2, QTR("Never scan for other playlists", nullptr));

        label_2->setText(QTR("&Minimum playlist duration:", nullptr));
        cbMIgnorePlaylistsForMenus->setText(QTR("&Ignore playlists meant for menus", nullptr));
        groupBox_21->setTitle(QTR("Blu-rays", nullptr));
        cbMAddBlurayCovers->setText(QTR("Add &Blu-ray cover images as attachments", nullptr));
        groupBox_17->setTitle(QTR("Defaults for jobs saving info tool output to text files", nullptr));
        groupBox_15->setTitle(QTR("Header editor", nullptr));
        label_14->setText(QTR("When &dropping files:", nullptr));
        cbHEDateTimeInUTC->setText(QTR("Show dates && times in &UTC instead of the local time zone", nullptr));
        groupBox_8->setTitle(QTR("Chapter editor", nullptr));
        cbCEDropLastFromBlurayPlaylist->setText(QTR("Drop last entry from imported &Blu-ray playlists if it's near the end", nullptr));
        label_17->setText(QTR("&Character set for text files:", nullptr));
        groupBox_13->setTitle(QTR("Defaults for new chapter entries", nullptr));
        label_7->setText(QTR("Na&me template:", nullptr));
        label_10->setText(QTR("Language:", nullptr));
        groupBox_4->setTitle(QTR("Jobs and job output", nullptr));
        cbGuiSwitchToJobOutputAfterStarting->setText(QTR("Always &switch to the job output tool after starting one immediately", nullptr));
        cbGuiUseDefaultJobDescription->setText(QTR("Always use a &default description when adding a job to the queue", nullptr));
        cbGuiShowOutputOfAllJobs->setText(QTR("Show &output of all jobs instead of current job only", nullptr));
        cbGuiResetJobWarningErrorCountersOnExit->setText(QTR("Reset the warning and error &counters on exit", nullptr));
        cbGuiRemoveOutputFileOnJobFailure->setText(QTR("Remove the output &file when a job ends with errors or when it is aborted", nullptr));
        cbGuiRemoveOldJobs->setText(QTR("Remove com&pleted jobs older than x days:", nullptr));
        cbGuiRemoveJobsOnExit->setText(QTR("Remove completed jobs from queue on &exit:", nullptr));
        cbGuiRemoveJobs->setText(QTR("&Remove job from queue after completion:", nullptr));
        cbGuiJobRemovalPolicy->setItemText(0, QTR("Only if the job completed successfully", nullptr));
        cbGuiJobRemovalPolicy->setItemText(1, QTR("Even if there were warnings", nullptr));
        cbGuiJobRemovalPolicy->setItemText(2, QTR("Even if there were errors", nullptr));

        cbGuiJobRemovalOnExitPolicy->setItemText(0, QTR("Only if the job completed successfully", nullptr));
        cbGuiJobRemovalOnExitPolicy->setItemText(1, QTR("Even if there were warnings", nullptr));
        cbGuiJobRemovalOnExitPolicy->setItemText(2, QTR("Even if there were errors", nullptr));

        label_22->setText(QTR("Ma&ximum number of concurrent jobs:", nullptr));
        groupBox_14->setTitle(QTR("Executing actions after certain events", nullptr));
        pbJobsAddProgram->setText(QTR("&Add action", nullptr));
        label_8->setText(QTR("No actions have been added yet.", nullptr));
    } // retranslateUi

};

} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Ui {
    class PreferencesDialog: public Ui_PreferencesDialog {};
} // namespace Ui
} // namespace gui
} // namespace mtx

#endif // PREFERENCES_DIALOG_H
